/*===- TableGen'erated file -------------------------------------*- C++ -*-===*\
|*                                                                            *|
|* Intrinsic Function Source Fragment                                         *|
|*                                                                            *|
|* Automatically generated file, do not edit!                                 *|
|*                                                                            *|
\*===----------------------------------------------------------------------===*/

#ifndef LLVM_IR_INTRINSIC_X86_ENUMS_H
#define LLVM_IR_INTRINSIC_X86_ENUMS_H
namespace llvm::Intrinsic {
enum X86Intrinsics : unsigned {
// Enum values for intrinsics.
    x86_aadd32 = 12956,                                // llvm.x86.aadd32
    x86_aadd64,                                // llvm.x86.aadd64
    x86_aand32,                                // llvm.x86.aand32
    x86_aand64,                                // llvm.x86.aand64
    x86_addcarry_32,                           // llvm.x86.addcarry.32
    x86_addcarry_64,                           // llvm.x86.addcarry.64
    x86_aesdec128kl,                           // llvm.x86.aesdec128kl
    x86_aesdec256kl,                           // llvm.x86.aesdec256kl
    x86_aesdecwide128kl,                       // llvm.x86.aesdecwide128kl
    x86_aesdecwide256kl,                       // llvm.x86.aesdecwide256kl
    x86_aesenc128kl,                           // llvm.x86.aesenc128kl
    x86_aesenc256kl,                           // llvm.x86.aesenc256kl
    x86_aesencwide128kl,                       // llvm.x86.aesencwide128kl
    x86_aesencwide256kl,                       // llvm.x86.aesencwide256kl
    x86_aesni_aesdec,                          // llvm.x86.aesni.aesdec
    x86_aesni_aesdec_256,                      // llvm.x86.aesni.aesdec.256
    x86_aesni_aesdec_512,                      // llvm.x86.aesni.aesdec.512
    x86_aesni_aesdeclast,                      // llvm.x86.aesni.aesdeclast
    x86_aesni_aesdeclast_256,                  // llvm.x86.aesni.aesdeclast.256
    x86_aesni_aesdeclast_512,                  // llvm.x86.aesni.aesdeclast.512
    x86_aesni_aesenc,                          // llvm.x86.aesni.aesenc
    x86_aesni_aesenc_256,                      // llvm.x86.aesni.aesenc.256
    x86_aesni_aesenc_512,                      // llvm.x86.aesni.aesenc.512
    x86_aesni_aesenclast,                      // llvm.x86.aesni.aesenclast
    x86_aesni_aesenclast_256,                  // llvm.x86.aesni.aesenclast.256
    x86_aesni_aesenclast_512,                  // llvm.x86.aesni.aesenclast.512
    x86_aesni_aesimc,                          // llvm.x86.aesni.aesimc
    x86_aesni_aeskeygenassist,                 // llvm.x86.aesni.aeskeygenassist
    x86_aor32,                                 // llvm.x86.aor32
    x86_aor64,                                 // llvm.x86.aor64
    x86_atomic_add_cc,                         // llvm.x86.atomic.add.cc
    x86_atomic_and_cc,                         // llvm.x86.atomic.and.cc
    x86_atomic_btc,                            // llvm.x86.atomic.btc
    x86_atomic_btc_rm,                         // llvm.x86.atomic.btc.rm
    x86_atomic_btr,                            // llvm.x86.atomic.btr
    x86_atomic_btr_rm,                         // llvm.x86.atomic.btr.rm
    x86_atomic_bts,                            // llvm.x86.atomic.bts
    x86_atomic_bts_rm,                         // llvm.x86.atomic.bts.rm
    x86_atomic_or_cc,                          // llvm.x86.atomic.or.cc
    x86_atomic_sub_cc,                         // llvm.x86.atomic.sub.cc
    x86_atomic_xor_cc,                         // llvm.x86.atomic.xor.cc
    x86_avx_addsub_pd_256,                     // llvm.x86.avx.addsub.pd.256
    x86_avx_addsub_ps_256,                     // llvm.x86.avx.addsub.ps.256
    x86_avx_blendv_pd_256,                     // llvm.x86.avx.blendv.pd.256
    x86_avx_blendv_ps_256,                     // llvm.x86.avx.blendv.ps.256
    x86_avx_cmp_pd_256,                        // llvm.x86.avx.cmp.pd.256
    x86_avx_cmp_ps_256,                        // llvm.x86.avx.cmp.ps.256
    x86_avx_cvt_pd2_ps_256,                    // llvm.x86.avx.cvt.pd2.ps.256
    x86_avx_cvt_pd2dq_256,                     // llvm.x86.avx.cvt.pd2dq.256
    x86_avx_cvt_ps2dq_256,                     // llvm.x86.avx.cvt.ps2dq.256
    x86_avx_cvtt_pd2dq_256,                    // llvm.x86.avx.cvtt.pd2dq.256
    x86_avx_cvtt_ps2dq_256,                    // llvm.x86.avx.cvtt.ps2dq.256
    x86_avx_dp_ps_256,                         // llvm.x86.avx.dp.ps.256
    x86_avx_hadd_pd_256,                       // llvm.x86.avx.hadd.pd.256
    x86_avx_hadd_ps_256,                       // llvm.x86.avx.hadd.ps.256
    x86_avx_hsub_pd_256,                       // llvm.x86.avx.hsub.pd.256
    x86_avx_hsub_ps_256,                       // llvm.x86.avx.hsub.ps.256
    x86_avx_ldu_dq_256,                        // llvm.x86.avx.ldu.dq.256
    x86_avx_maskload_pd,                       // llvm.x86.avx.maskload.pd
    x86_avx_maskload_pd_256,                   // llvm.x86.avx.maskload.pd.256
    x86_avx_maskload_ps,                       // llvm.x86.avx.maskload.ps
    x86_avx_maskload_ps_256,                   // llvm.x86.avx.maskload.ps.256
    x86_avx_maskstore_pd,                      // llvm.x86.avx.maskstore.pd
    x86_avx_maskstore_pd_256,                  // llvm.x86.avx.maskstore.pd.256
    x86_avx_maskstore_ps,                      // llvm.x86.avx.maskstore.ps
    x86_avx_maskstore_ps_256,                  // llvm.x86.avx.maskstore.ps.256
    x86_avx_max_pd_256,                        // llvm.x86.avx.max.pd.256
    x86_avx_max_ps_256,                        // llvm.x86.avx.max.ps.256
    x86_avx_min_pd_256,                        // llvm.x86.avx.min.pd.256
    x86_avx_min_ps_256,                        // llvm.x86.avx.min.ps.256
    x86_avx_movmsk_pd_256,                     // llvm.x86.avx.movmsk.pd.256
    x86_avx_movmsk_ps_256,                     // llvm.x86.avx.movmsk.ps.256
    x86_avx_ptestc_256,                        // llvm.x86.avx.ptestc.256
    x86_avx_ptestnzc_256,                      // llvm.x86.avx.ptestnzc.256
    x86_avx_ptestz_256,                        // llvm.x86.avx.ptestz.256
    x86_avx_rcp_ps_256,                        // llvm.x86.avx.rcp.ps.256
    x86_avx_round_pd_256,                      // llvm.x86.avx.round.pd.256
    x86_avx_round_ps_256,                      // llvm.x86.avx.round.ps.256
    x86_avx_rsqrt_ps_256,                      // llvm.x86.avx.rsqrt.ps.256
    x86_avx_vpermilvar_pd,                     // llvm.x86.avx.vpermilvar.pd
    x86_avx_vpermilvar_pd_256,                 // llvm.x86.avx.vpermilvar.pd.256
    x86_avx_vpermilvar_ps,                     // llvm.x86.avx.vpermilvar.ps
    x86_avx_vpermilvar_ps_256,                 // llvm.x86.avx.vpermilvar.ps.256
    x86_avx_vtestc_pd,                         // llvm.x86.avx.vtestc.pd
    x86_avx_vtestc_pd_256,                     // llvm.x86.avx.vtestc.pd.256
    x86_avx_vtestc_ps,                         // llvm.x86.avx.vtestc.ps
    x86_avx_vtestc_ps_256,                     // llvm.x86.avx.vtestc.ps.256
    x86_avx_vtestnzc_pd,                       // llvm.x86.avx.vtestnzc.pd
    x86_avx_vtestnzc_pd_256,                   // llvm.x86.avx.vtestnzc.pd.256
    x86_avx_vtestnzc_ps,                       // llvm.x86.avx.vtestnzc.ps
    x86_avx_vtestnzc_ps_256,                   // llvm.x86.avx.vtestnzc.ps.256
    x86_avx_vtestz_pd,                         // llvm.x86.avx.vtestz.pd
    x86_avx_vtestz_pd_256,                     // llvm.x86.avx.vtestz.pd.256
    x86_avx_vtestz_ps,                         // llvm.x86.avx.vtestz.ps
    x86_avx_vtestz_ps_256,                     // llvm.x86.avx.vtestz.ps.256
    x86_avx_vzeroall,                          // llvm.x86.avx.vzeroall
    x86_avx_vzeroupper,                        // llvm.x86.avx.vzeroupper
    x86_avx10_fpclass_bf16_128,                // llvm.x86.avx10.fpclass.bf16.128
    x86_avx10_fpclass_bf16_256,                // llvm.x86.avx10.fpclass.bf16.256
    x86_avx10_fpclass_bf16_512,                // llvm.x86.avx10.fpclass.bf16.512
    x86_avx10_mask_getexp_bf16_128,            // llvm.x86.avx10.mask.getexp.bf16.128
    x86_avx10_mask_getexp_bf16_256,            // llvm.x86.avx10.mask.getexp.bf16.256
    x86_avx10_mask_getexp_bf16_512,            // llvm.x86.avx10.mask.getexp.bf16.512
    x86_avx10_mask_getmant_bf16_128,           // llvm.x86.avx10.mask.getmant.bf16.128
    x86_avx10_mask_getmant_bf16_256,           // llvm.x86.avx10.mask.getmant.bf16.256
    x86_avx10_mask_getmant_bf16_512,           // llvm.x86.avx10.mask.getmant.bf16.512
    x86_avx10_mask_rcp_bf16_128,               // llvm.x86.avx10.mask.rcp.bf16.128
    x86_avx10_mask_rcp_bf16_256,               // llvm.x86.avx10.mask.rcp.bf16.256
    x86_avx10_mask_rcp_bf16_512,               // llvm.x86.avx10.mask.rcp.bf16.512
    x86_avx10_mask_reduce_bf16_128,            // llvm.x86.avx10.mask.reduce.bf16.128
    x86_avx10_mask_reduce_bf16_256,            // llvm.x86.avx10.mask.reduce.bf16.256
    x86_avx10_mask_reduce_bf16_512,            // llvm.x86.avx10.mask.reduce.bf16.512
    x86_avx10_mask_rndscale_bf16_128,          // llvm.x86.avx10.mask.rndscale.bf16.128
    x86_avx10_mask_rndscale_bf16_256,          // llvm.x86.avx10.mask.rndscale.bf16.256
    x86_avx10_mask_rndscale_bf16_512,          // llvm.x86.avx10.mask.rndscale.bf16.512
    x86_avx10_mask_rsqrt_bf16_128,             // llvm.x86.avx10.mask.rsqrt.bf16.128
    x86_avx10_mask_rsqrt_bf16_256,             // llvm.x86.avx10.mask.rsqrt.bf16.256
    x86_avx10_mask_rsqrt_bf16_512,             // llvm.x86.avx10.mask.rsqrt.bf16.512
    x86_avx10_mask_scalef_bf16_128,            // llvm.x86.avx10.mask.scalef.bf16.128
    x86_avx10_mask_scalef_bf16_256,            // llvm.x86.avx10.mask.scalef.bf16.256
    x86_avx10_mask_scalef_bf16_512,            // llvm.x86.avx10.mask.scalef.bf16.512
    x86_avx10_mask_vcmppd256,                  // llvm.x86.avx10.mask.vcmppd256
    x86_avx10_mask_vcmpph256,                  // llvm.x86.avx10.mask.vcmpph256
    x86_avx10_mask_vcmpps256,                  // llvm.x86.avx10.mask.vcmpps256
    x86_avx10_mask_vcvt2ps2phx_128,            // llvm.x86.avx10.mask.vcvt2ps2phx.128
    x86_avx10_mask_vcvt2ps2phx_256,            // llvm.x86.avx10.mask.vcvt2ps2phx.256
    x86_avx10_mask_vcvt2ps2phx_512,            // llvm.x86.avx10.mask.vcvt2ps2phx.512
    x86_avx10_mask_vcvtbiasph2bf8128,          // llvm.x86.avx10.mask.vcvtbiasph2bf8128
    x86_avx10_mask_vcvtbiasph2bf8256,          // llvm.x86.avx10.mask.vcvtbiasph2bf8256
    x86_avx10_mask_vcvtbiasph2bf8512,          // llvm.x86.avx10.mask.vcvtbiasph2bf8512
    x86_avx10_mask_vcvtbiasph2bf8s128,         // llvm.x86.avx10.mask.vcvtbiasph2bf8s128
    x86_avx10_mask_vcvtbiasph2bf8s256,         // llvm.x86.avx10.mask.vcvtbiasph2bf8s256
    x86_avx10_mask_vcvtbiasph2bf8s512,         // llvm.x86.avx10.mask.vcvtbiasph2bf8s512
    x86_avx10_mask_vcvtbiasph2hf8128,          // llvm.x86.avx10.mask.vcvtbiasph2hf8128
    x86_avx10_mask_vcvtbiasph2hf8256,          // llvm.x86.avx10.mask.vcvtbiasph2hf8256
    x86_avx10_mask_vcvtbiasph2hf8512,          // llvm.x86.avx10.mask.vcvtbiasph2hf8512
    x86_avx10_mask_vcvtbiasph2hf8s128,         // llvm.x86.avx10.mask.vcvtbiasph2hf8s128
    x86_avx10_mask_vcvtbiasph2hf8s256,         // llvm.x86.avx10.mask.vcvtbiasph2hf8s256
    x86_avx10_mask_vcvtbiasph2hf8s512,         // llvm.x86.avx10.mask.vcvtbiasph2hf8s512
    x86_avx10_mask_vcvthf82ph128,              // llvm.x86.avx10.mask.vcvthf82ph128
    x86_avx10_mask_vcvthf82ph256,              // llvm.x86.avx10.mask.vcvthf82ph256
    x86_avx10_mask_vcvthf82ph512,              // llvm.x86.avx10.mask.vcvthf82ph512
    x86_avx10_mask_vcvtpd2dq256,               // llvm.x86.avx10.mask.vcvtpd2dq256
    x86_avx10_mask_vcvtpd2ph256,               // llvm.x86.avx10.mask.vcvtpd2ph256
    x86_avx10_mask_vcvtpd2ps256,               // llvm.x86.avx10.mask.vcvtpd2ps256
    x86_avx10_mask_vcvtpd2qq256,               // llvm.x86.avx10.mask.vcvtpd2qq256
    x86_avx10_mask_vcvtpd2udq256,              // llvm.x86.avx10.mask.vcvtpd2udq256
    x86_avx10_mask_vcvtpd2uqq256,              // llvm.x86.avx10.mask.vcvtpd2uqq256
    x86_avx10_mask_vcvtph2bf8128,              // llvm.x86.avx10.mask.vcvtph2bf8128
    x86_avx10_mask_vcvtph2bf8256,              // llvm.x86.avx10.mask.vcvtph2bf8256
    x86_avx10_mask_vcvtph2bf8512,              // llvm.x86.avx10.mask.vcvtph2bf8512
    x86_avx10_mask_vcvtph2bf8s128,             // llvm.x86.avx10.mask.vcvtph2bf8s128
    x86_avx10_mask_vcvtph2bf8s256,             // llvm.x86.avx10.mask.vcvtph2bf8s256
    x86_avx10_mask_vcvtph2bf8s512,             // llvm.x86.avx10.mask.vcvtph2bf8s512
    x86_avx10_mask_vcvtph2dq256,               // llvm.x86.avx10.mask.vcvtph2dq256
    x86_avx10_mask_vcvtph2hf8128,              // llvm.x86.avx10.mask.vcvtph2hf8128
    x86_avx10_mask_vcvtph2hf8256,              // llvm.x86.avx10.mask.vcvtph2hf8256
    x86_avx10_mask_vcvtph2hf8512,              // llvm.x86.avx10.mask.vcvtph2hf8512
    x86_avx10_mask_vcvtph2hf8s128,             // llvm.x86.avx10.mask.vcvtph2hf8s128
    x86_avx10_mask_vcvtph2hf8s256,             // llvm.x86.avx10.mask.vcvtph2hf8s256
    x86_avx10_mask_vcvtph2hf8s512,             // llvm.x86.avx10.mask.vcvtph2hf8s512
    x86_avx10_mask_vcvtph2ibs128,              // llvm.x86.avx10.mask.vcvtph2ibs128
    x86_avx10_mask_vcvtph2ibs256,              // llvm.x86.avx10.mask.vcvtph2ibs256
    x86_avx10_mask_vcvtph2ibs512,              // llvm.x86.avx10.mask.vcvtph2ibs512
    x86_avx10_mask_vcvtph2iubs128,             // llvm.x86.avx10.mask.vcvtph2iubs128
    x86_avx10_mask_vcvtph2iubs256,             // llvm.x86.avx10.mask.vcvtph2iubs256
    x86_avx10_mask_vcvtph2iubs512,             // llvm.x86.avx10.mask.vcvtph2iubs512
    x86_avx10_mask_vcvtph2pd256,               // llvm.x86.avx10.mask.vcvtph2pd256
    x86_avx10_mask_vcvtph2psx256,              // llvm.x86.avx10.mask.vcvtph2psx256
    x86_avx10_mask_vcvtph2qq256,               // llvm.x86.avx10.mask.vcvtph2qq256
    x86_avx10_mask_vcvtph2udq256,              // llvm.x86.avx10.mask.vcvtph2udq256
    x86_avx10_mask_vcvtph2uqq256,              // llvm.x86.avx10.mask.vcvtph2uqq256
    x86_avx10_mask_vcvtph2uw256,               // llvm.x86.avx10.mask.vcvtph2uw256
    x86_avx10_mask_vcvtph2w256,                // llvm.x86.avx10.mask.vcvtph2w256
    x86_avx10_mask_vcvtps2dq256,               // llvm.x86.avx10.mask.vcvtps2dq256
    x86_avx10_mask_vcvtps2ibs128,              // llvm.x86.avx10.mask.vcvtps2ibs128
    x86_avx10_mask_vcvtps2ibs256,              // llvm.x86.avx10.mask.vcvtps2ibs256
    x86_avx10_mask_vcvtps2ibs512,              // llvm.x86.avx10.mask.vcvtps2ibs512
    x86_avx10_mask_vcvtps2iubs128,             // llvm.x86.avx10.mask.vcvtps2iubs128
    x86_avx10_mask_vcvtps2iubs256,             // llvm.x86.avx10.mask.vcvtps2iubs256
    x86_avx10_mask_vcvtps2iubs512,             // llvm.x86.avx10.mask.vcvtps2iubs512
    x86_avx10_mask_vcvtps2pd256,               // llvm.x86.avx10.mask.vcvtps2pd256
    x86_avx10_mask_vcvtps2ph256,               // llvm.x86.avx10.mask.vcvtps2ph256
    x86_avx10_mask_vcvtps2phx256,              // llvm.x86.avx10.mask.vcvtps2phx256
    x86_avx10_mask_vcvtps2qq256,               // llvm.x86.avx10.mask.vcvtps2qq256
    x86_avx10_mask_vcvtps2udq256,              // llvm.x86.avx10.mask.vcvtps2udq256
    x86_avx10_mask_vcvtps2uqq256,              // llvm.x86.avx10.mask.vcvtps2uqq256
    x86_avx10_mask_vcvttpd2dq256,              // llvm.x86.avx10.mask.vcvttpd2dq256
    x86_avx10_mask_vcvttpd2dqs_128,            // llvm.x86.avx10.mask.vcvttpd2dqs.128
    x86_avx10_mask_vcvttpd2dqs_round_256,      // llvm.x86.avx10.mask.vcvttpd2dqs.round.256
    x86_avx10_mask_vcvttpd2dqs_round_512,      // llvm.x86.avx10.mask.vcvttpd2dqs.round.512
    x86_avx10_mask_vcvttpd2qq256,              // llvm.x86.avx10.mask.vcvttpd2qq256
    x86_avx10_mask_vcvttpd2qqs_128,            // llvm.x86.avx10.mask.vcvttpd2qqs.128
    x86_avx10_mask_vcvttpd2qqs_round_256,      // llvm.x86.avx10.mask.vcvttpd2qqs.round.256
    x86_avx10_mask_vcvttpd2qqs_round_512,      // llvm.x86.avx10.mask.vcvttpd2qqs.round.512
    x86_avx10_mask_vcvttpd2udq256,             // llvm.x86.avx10.mask.vcvttpd2udq256
    x86_avx10_mask_vcvttpd2udqs_128,           // llvm.x86.avx10.mask.vcvttpd2udqs.128
    x86_avx10_mask_vcvttpd2udqs_round_256,     // llvm.x86.avx10.mask.vcvttpd2udqs.round.256
    x86_avx10_mask_vcvttpd2udqs_round_512,     // llvm.x86.avx10.mask.vcvttpd2udqs.round.512
    x86_avx10_mask_vcvttpd2uqq256,             // llvm.x86.avx10.mask.vcvttpd2uqq256
    x86_avx10_mask_vcvttpd2uqqs_128,           // llvm.x86.avx10.mask.vcvttpd2uqqs.128
    x86_avx10_mask_vcvttpd2uqqs_round_256,     // llvm.x86.avx10.mask.vcvttpd2uqqs.round.256
    x86_avx10_mask_vcvttpd2uqqs_round_512,     // llvm.x86.avx10.mask.vcvttpd2uqqs.round.512
    x86_avx10_mask_vcvttph2dq256,              // llvm.x86.avx10.mask.vcvttph2dq256
    x86_avx10_mask_vcvttph2ibs128,             // llvm.x86.avx10.mask.vcvttph2ibs128
    x86_avx10_mask_vcvttph2ibs256,             // llvm.x86.avx10.mask.vcvttph2ibs256
    x86_avx10_mask_vcvttph2ibs512,             // llvm.x86.avx10.mask.vcvttph2ibs512
    x86_avx10_mask_vcvttph2iubs128,            // llvm.x86.avx10.mask.vcvttph2iubs128
    x86_avx10_mask_vcvttph2iubs256,            // llvm.x86.avx10.mask.vcvttph2iubs256
    x86_avx10_mask_vcvttph2iubs512,            // llvm.x86.avx10.mask.vcvttph2iubs512
    x86_avx10_mask_vcvttph2qq256,              // llvm.x86.avx10.mask.vcvttph2qq256
    x86_avx10_mask_vcvttph2udq256,             // llvm.x86.avx10.mask.vcvttph2udq256
    x86_avx10_mask_vcvttph2uqq256,             // llvm.x86.avx10.mask.vcvttph2uqq256
    x86_avx10_mask_vcvttph2uw256,              // llvm.x86.avx10.mask.vcvttph2uw256
    x86_avx10_mask_vcvttph2w256,               // llvm.x86.avx10.mask.vcvttph2w256
    x86_avx10_mask_vcvttps2dq256,              // llvm.x86.avx10.mask.vcvttps2dq256
    x86_avx10_mask_vcvttps2dqs_128,            // llvm.x86.avx10.mask.vcvttps2dqs.128
    x86_avx10_mask_vcvttps2dqs_round_256,      // llvm.x86.avx10.mask.vcvttps2dqs.round.256
    x86_avx10_mask_vcvttps2dqs_round_512,      // llvm.x86.avx10.mask.vcvttps2dqs.round.512
    x86_avx10_mask_vcvttps2ibs128,             // llvm.x86.avx10.mask.vcvttps2ibs128
    x86_avx10_mask_vcvttps2ibs256,             // llvm.x86.avx10.mask.vcvttps2ibs256
    x86_avx10_mask_vcvttps2ibs512,             // llvm.x86.avx10.mask.vcvttps2ibs512
    x86_avx10_mask_vcvttps2iubs128,            // llvm.x86.avx10.mask.vcvttps2iubs128
    x86_avx10_mask_vcvttps2iubs256,            // llvm.x86.avx10.mask.vcvttps2iubs256
    x86_avx10_mask_vcvttps2iubs512,            // llvm.x86.avx10.mask.vcvttps2iubs512
    x86_avx10_mask_vcvttps2qq256,              // llvm.x86.avx10.mask.vcvttps2qq256
    x86_avx10_mask_vcvttps2qqs_128,            // llvm.x86.avx10.mask.vcvttps2qqs.128
    x86_avx10_mask_vcvttps2qqs_round_256,      // llvm.x86.avx10.mask.vcvttps2qqs.round.256
    x86_avx10_mask_vcvttps2qqs_round_512,      // llvm.x86.avx10.mask.vcvttps2qqs.round.512
    x86_avx10_mask_vcvttps2udq256,             // llvm.x86.avx10.mask.vcvttps2udq256
    x86_avx10_mask_vcvttps2udqs_128,           // llvm.x86.avx10.mask.vcvttps2udqs.128
    x86_avx10_mask_vcvttps2udqs_round_256,     // llvm.x86.avx10.mask.vcvttps2udqs.round.256
    x86_avx10_mask_vcvttps2udqs_round_512,     // llvm.x86.avx10.mask.vcvttps2udqs.round.512
    x86_avx10_mask_vcvttps2uqq256,             // llvm.x86.avx10.mask.vcvttps2uqq256
    x86_avx10_mask_vcvttps2uqqs_128,           // llvm.x86.avx10.mask.vcvttps2uqqs.128
    x86_avx10_mask_vcvttps2uqqs_round_256,     // llvm.x86.avx10.mask.vcvttps2uqqs.round.256
    x86_avx10_mask_vcvttps2uqqs_round_512,     // llvm.x86.avx10.mask.vcvttps2uqqs.round.512
    x86_avx10_mask_vfcmaddcph256,              // llvm.x86.avx10.mask.vfcmaddcph256
    x86_avx10_mask_vfcmulcph256,               // llvm.x86.avx10.mask.vfcmulcph256
    x86_avx10_mask_vfixupimmpd256,             // llvm.x86.avx10.mask.vfixupimmpd256
    x86_avx10_mask_vfixupimmps256,             // llvm.x86.avx10.mask.vfixupimmps256
    x86_avx10_mask_vfmaddcph256,               // llvm.x86.avx10.mask.vfmaddcph256
    x86_avx10_mask_vfmulcph256,                // llvm.x86.avx10.mask.vfmulcph256
    x86_avx10_mask_vgetexppd256,               // llvm.x86.avx10.mask.vgetexppd256
    x86_avx10_mask_vgetexpph256,               // llvm.x86.avx10.mask.vgetexpph256
    x86_avx10_mask_vgetexpps256,               // llvm.x86.avx10.mask.vgetexpps256
    x86_avx10_mask_vgetmantpd256,              // llvm.x86.avx10.mask.vgetmantpd256
    x86_avx10_mask_vgetmantph256,              // llvm.x86.avx10.mask.vgetmantph256
    x86_avx10_mask_vgetmantps256,              // llvm.x86.avx10.mask.vgetmantps256
    x86_avx10_mask_vminmaxpd_round,            // llvm.x86.avx10.mask.vminmaxpd.round
    x86_avx10_mask_vminmaxpd128,               // llvm.x86.avx10.mask.vminmaxpd128
    x86_avx10_mask_vminmaxpd256_round,         // llvm.x86.avx10.mask.vminmaxpd256.round
    x86_avx10_mask_vminmaxph_round,            // llvm.x86.avx10.mask.vminmaxph.round
    x86_avx10_mask_vminmaxph128,               // llvm.x86.avx10.mask.vminmaxph128
    x86_avx10_mask_vminmaxph256_round,         // llvm.x86.avx10.mask.vminmaxph256.round
    x86_avx10_mask_vminmaxps_round,            // llvm.x86.avx10.mask.vminmaxps.round
    x86_avx10_mask_vminmaxps128,               // llvm.x86.avx10.mask.vminmaxps128
    x86_avx10_mask_vminmaxps256_round,         // llvm.x86.avx10.mask.vminmaxps256.round
    x86_avx10_mask_vminmaxsd_round,            // llvm.x86.avx10.mask.vminmaxsd.round
    x86_avx10_mask_vminmaxsh_round,            // llvm.x86.avx10.mask.vminmaxsh.round
    x86_avx10_mask_vminmaxss_round,            // llvm.x86.avx10.mask.vminmaxss.round
    x86_avx10_mask_vrangepd256,                // llvm.x86.avx10.mask.vrangepd256
    x86_avx10_mask_vrangeps256,                // llvm.x86.avx10.mask.vrangeps256
    x86_avx10_mask_vreducepd256,               // llvm.x86.avx10.mask.vreducepd256
    x86_avx10_mask_vreduceph256,               // llvm.x86.avx10.mask.vreduceph256
    x86_avx10_mask_vreduceps256,               // llvm.x86.avx10.mask.vreduceps256
    x86_avx10_mask_vrndscalepd256,             // llvm.x86.avx10.mask.vrndscalepd256
    x86_avx10_mask_vrndscaleph256,             // llvm.x86.avx10.mask.vrndscaleph256
    x86_avx10_mask_vrndscaleps256,             // llvm.x86.avx10.mask.vrndscaleps256
    x86_avx10_mask_vscalefpd256,               // llvm.x86.avx10.mask.vscalefpd256
    x86_avx10_mask_vscalefph256,               // llvm.x86.avx10.mask.vscalefph256
    x86_avx10_mask_vscalefps256,               // llvm.x86.avx10.mask.vscalefps256
    x86_avx10_maskz_vfcmaddcph256,             // llvm.x86.avx10.maskz.vfcmaddcph256
    x86_avx10_maskz_vfixupimmpd256,            // llvm.x86.avx10.maskz.vfixupimmpd256
    x86_avx10_maskz_vfixupimmps256,            // llvm.x86.avx10.maskz.vfixupimmps256
    x86_avx10_maskz_vfmaddcph256,              // llvm.x86.avx10.maskz.vfmaddcph256
    x86_avx10_vaddbf16128,                     // llvm.x86.avx10.vaddbf16128
    x86_avx10_vaddbf16256,                     // llvm.x86.avx10.vaddbf16256
    x86_avx10_vaddbf16512,                     // llvm.x86.avx10.vaddbf16512
    x86_avx10_vaddpd256,                       // llvm.x86.avx10.vaddpd256
    x86_avx10_vaddph256,                       // llvm.x86.avx10.vaddph256
    x86_avx10_vaddps256,                       // llvm.x86.avx10.vaddps256
    x86_avx10_vcomisbf16eq,                    // llvm.x86.avx10.vcomisbf16eq
    x86_avx10_vcomisbf16ge,                    // llvm.x86.avx10.vcomisbf16ge
    x86_avx10_vcomisbf16gt,                    // llvm.x86.avx10.vcomisbf16gt
    x86_avx10_vcomisbf16le,                    // llvm.x86.avx10.vcomisbf16le
    x86_avx10_vcomisbf16lt,                    // llvm.x86.avx10.vcomisbf16lt
    x86_avx10_vcomisbf16neq,                   // llvm.x86.avx10.vcomisbf16neq
    x86_avx10_vcvt2ph2bf8128,                  // llvm.x86.avx10.vcvt2ph2bf8128
    x86_avx10_vcvt2ph2bf8256,                  // llvm.x86.avx10.vcvt2ph2bf8256
    x86_avx10_vcvt2ph2bf8512,                  // llvm.x86.avx10.vcvt2ph2bf8512
    x86_avx10_vcvt2ph2bf8s128,                 // llvm.x86.avx10.vcvt2ph2bf8s128
    x86_avx10_vcvt2ph2bf8s256,                 // llvm.x86.avx10.vcvt2ph2bf8s256
    x86_avx10_vcvt2ph2bf8s512,                 // llvm.x86.avx10.vcvt2ph2bf8s512
    x86_avx10_vcvt2ph2hf8128,                  // llvm.x86.avx10.vcvt2ph2hf8128
    x86_avx10_vcvt2ph2hf8256,                  // llvm.x86.avx10.vcvt2ph2hf8256
    x86_avx10_vcvt2ph2hf8512,                  // llvm.x86.avx10.vcvt2ph2hf8512
    x86_avx10_vcvt2ph2hf8s128,                 // llvm.x86.avx10.vcvt2ph2hf8s128
    x86_avx10_vcvt2ph2hf8s256,                 // llvm.x86.avx10.vcvt2ph2hf8s256
    x86_avx10_vcvt2ph2hf8s512,                 // llvm.x86.avx10.vcvt2ph2hf8s512
    x86_avx10_vcvtbf162ibs128,                 // llvm.x86.avx10.vcvtbf162ibs128
    x86_avx10_vcvtbf162ibs256,                 // llvm.x86.avx10.vcvtbf162ibs256
    x86_avx10_vcvtbf162ibs512,                 // llvm.x86.avx10.vcvtbf162ibs512
    x86_avx10_vcvtbf162iubs128,                // llvm.x86.avx10.vcvtbf162iubs128
    x86_avx10_vcvtbf162iubs256,                // llvm.x86.avx10.vcvtbf162iubs256
    x86_avx10_vcvtbf162iubs512,                // llvm.x86.avx10.vcvtbf162iubs512
    x86_avx10_vcvttbf162ibs128,                // llvm.x86.avx10.vcvttbf162ibs128
    x86_avx10_vcvttbf162ibs256,                // llvm.x86.avx10.vcvttbf162ibs256
    x86_avx10_vcvttbf162ibs512,                // llvm.x86.avx10.vcvttbf162ibs512
    x86_avx10_vcvttbf162iubs128,               // llvm.x86.avx10.vcvttbf162iubs128
    x86_avx10_vcvttbf162iubs256,               // llvm.x86.avx10.vcvttbf162iubs256
    x86_avx10_vcvttbf162iubs512,               // llvm.x86.avx10.vcvttbf162iubs512
    x86_avx10_vcvttsd2sis,                     // llvm.x86.avx10.vcvttsd2sis
    x86_avx10_vcvttsd2sis64,                   // llvm.x86.avx10.vcvttsd2sis64
    x86_avx10_vcvttsd2usis,                    // llvm.x86.avx10.vcvttsd2usis
    x86_avx10_vcvttsd2usis64,                  // llvm.x86.avx10.vcvttsd2usis64
    x86_avx10_vcvttss2sis,                     // llvm.x86.avx10.vcvttss2sis
    x86_avx10_vcvttss2sis64,                   // llvm.x86.avx10.vcvttss2sis64
    x86_avx10_vcvttss2usis,                    // llvm.x86.avx10.vcvttss2usis
    x86_avx10_vcvttss2usis64,                  // llvm.x86.avx10.vcvttss2usis64
    x86_avx10_vdivbf16128,                     // llvm.x86.avx10.vdivbf16128
    x86_avx10_vdivbf16256,                     // llvm.x86.avx10.vdivbf16256
    x86_avx10_vdivbf16512,                     // llvm.x86.avx10.vdivbf16512
    x86_avx10_vdivpd256,                       // llvm.x86.avx10.vdivpd256
    x86_avx10_vdivph256,                       // llvm.x86.avx10.vdivph256
    x86_avx10_vdivps256,                       // llvm.x86.avx10.vdivps256
    x86_avx10_vdpphps_128,                     // llvm.x86.avx10.vdpphps.128
    x86_avx10_vdpphps_256,                     // llvm.x86.avx10.vdpphps.256
    x86_avx10_vdpphps_512,                     // llvm.x86.avx10.vdpphps.512
    x86_avx10_vfmadd132bf16128,                // llvm.x86.avx10.vfmadd132bf16128
    x86_avx10_vfmadd132bf16256,                // llvm.x86.avx10.vfmadd132bf16256
    x86_avx10_vfmadd132bf16512,                // llvm.x86.avx10.vfmadd132bf16512
    x86_avx10_vfmadd213bf16128,                // llvm.x86.avx10.vfmadd213bf16128
    x86_avx10_vfmadd213bf16256,                // llvm.x86.avx10.vfmadd213bf16256
    x86_avx10_vfmadd231bf16128,                // llvm.x86.avx10.vfmadd231bf16128
    x86_avx10_vfmadd231bf16256,                // llvm.x86.avx10.vfmadd231bf16256
    x86_avx10_vfmadd231bf16512,                // llvm.x86.avx10.vfmadd231bf16512
    x86_avx10_vfmaddpd256,                     // llvm.x86.avx10.vfmaddpd256
    x86_avx10_vfmaddph256,                     // llvm.x86.avx10.vfmaddph256
    x86_avx10_vfmaddps256,                     // llvm.x86.avx10.vfmaddps256
    x86_avx10_vfmaddsubpd256,                  // llvm.x86.avx10.vfmaddsubpd256
    x86_avx10_vfmaddsubph256,                  // llvm.x86.avx10.vfmaddsubph256
    x86_avx10_vfmaddsubps256,                  // llvm.x86.avx10.vfmaddsubps256
    x86_avx10_vfmsub132bf16128,                // llvm.x86.avx10.vfmsub132bf16128
    x86_avx10_vfmsub132bf16256,                // llvm.x86.avx10.vfmsub132bf16256
    x86_avx10_vfmsub132bf16512,                // llvm.x86.avx10.vfmsub132bf16512
    x86_avx10_vfmsub213bf16128,                // llvm.x86.avx10.vfmsub213bf16128
    x86_avx10_vfmsub213bf16256,                // llvm.x86.avx10.vfmsub213bf16256
    x86_avx10_vfmsub213bf16512,                // llvm.x86.avx10.vfmsub213bf16512
    x86_avx10_vfmsub231bf16128,                // llvm.x86.avx10.vfmsub231bf16128
    x86_avx10_vfmsub231bf16256,                // llvm.x86.avx10.vfmsub231bf16256
    x86_avx10_vfmsub231bf16512,                // llvm.x86.avx10.vfmsub231bf16512
    x86_avx10_vfnmadd132bf16128,               // llvm.x86.avx10.vfnmadd132bf16128
    x86_avx10_vfnmadd132bf16256,               // llvm.x86.avx10.vfnmadd132bf16256
    x86_avx10_vfnmadd132bf16512,               // llvm.x86.avx10.vfnmadd132bf16512
    x86_avx10_vfnmadd213bf16128,               // llvm.x86.avx10.vfnmadd213bf16128
    x86_avx10_vfnmadd213bf16256,               // llvm.x86.avx10.vfnmadd213bf16256
    x86_avx10_vfnmadd213bf16512,               // llvm.x86.avx10.vfnmadd213bf16512
    x86_avx10_vfnmadd231bf16128,               // llvm.x86.avx10.vfnmadd231bf16128
    x86_avx10_vfnmadd231bf16256,               // llvm.x86.avx10.vfnmadd231bf16256
    x86_avx10_vfnmadd231bf16512,               // llvm.x86.avx10.vfnmadd231bf16512
    x86_avx10_vfnmsub132bf16128,               // llvm.x86.avx10.vfnmsub132bf16128
    x86_avx10_vfnmsub132bf16256,               // llvm.x86.avx10.vfnmsub132bf16256
    x86_avx10_vfnmsub132bf16512,               // llvm.x86.avx10.vfnmsub132bf16512
    x86_avx10_vfnmsub213bf16128,               // llvm.x86.avx10.vfnmsub213bf16128
    x86_avx10_vfnmsub213bf16256,               // llvm.x86.avx10.vfnmsub213bf16256
    x86_avx10_vfnmsub213bf16512,               // llvm.x86.avx10.vfnmsub213bf16512
    x86_avx10_vfnmsub231bf16128,               // llvm.x86.avx10.vfnmsub231bf16128
    x86_avx10_vfnmsub231bf16256,               // llvm.x86.avx10.vfnmsub231bf16256
    x86_avx10_vfnmsub231bf16512,               // llvm.x86.avx10.vfnmsub231bf16512
    x86_avx10_vmaxbf16128,                     // llvm.x86.avx10.vmaxbf16128
    x86_avx10_vmaxbf16256,                     // llvm.x86.avx10.vmaxbf16256
    x86_avx10_vmaxbf16512,                     // llvm.x86.avx10.vmaxbf16512
    x86_avx10_vmaxpd256,                       // llvm.x86.avx10.vmaxpd256
    x86_avx10_vmaxph256,                       // llvm.x86.avx10.vmaxph256
    x86_avx10_vmaxps256,                       // llvm.x86.avx10.vmaxps256
    x86_avx10_vminbf16128,                     // llvm.x86.avx10.vminbf16128
    x86_avx10_vminbf16256,                     // llvm.x86.avx10.vminbf16256
    x86_avx10_vminbf16512,                     // llvm.x86.avx10.vminbf16512
    x86_avx10_vminmaxbf16128,                  // llvm.x86.avx10.vminmaxbf16128
    x86_avx10_vminmaxbf16256,                  // llvm.x86.avx10.vminmaxbf16256
    x86_avx10_vminmaxbf16512,                  // llvm.x86.avx10.vminmaxbf16512
    x86_avx10_vminmaxpd128,                    // llvm.x86.avx10.vminmaxpd128
    x86_avx10_vminmaxpd256,                    // llvm.x86.avx10.vminmaxpd256
    x86_avx10_vminmaxph128,                    // llvm.x86.avx10.vminmaxph128
    x86_avx10_vminmaxph256,                    // llvm.x86.avx10.vminmaxph256
    x86_avx10_vminmaxps128,                    // llvm.x86.avx10.vminmaxps128
    x86_avx10_vminmaxps256,                    // llvm.x86.avx10.vminmaxps256
    x86_avx10_vminpd256,                       // llvm.x86.avx10.vminpd256
    x86_avx10_vminph256,                       // llvm.x86.avx10.vminph256
    x86_avx10_vminps256,                       // llvm.x86.avx10.vminps256
    x86_avx10_vmovrsb128,                      // llvm.x86.avx10.vmovrsb128
    x86_avx10_vmovrsb256,                      // llvm.x86.avx10.vmovrsb256
    x86_avx10_vmovrsb512,                      // llvm.x86.avx10.vmovrsb512
    x86_avx10_vmovrsd128,                      // llvm.x86.avx10.vmovrsd128
    x86_avx10_vmovrsd256,                      // llvm.x86.avx10.vmovrsd256
    x86_avx10_vmovrsd512,                      // llvm.x86.avx10.vmovrsd512
    x86_avx10_vmovrsq128,                      // llvm.x86.avx10.vmovrsq128
    x86_avx10_vmovrsq256,                      // llvm.x86.avx10.vmovrsq256
    x86_avx10_vmovrsq512,                      // llvm.x86.avx10.vmovrsq512
    x86_avx10_vmovrsw128,                      // llvm.x86.avx10.vmovrsw128
    x86_avx10_vmovrsw256,                      // llvm.x86.avx10.vmovrsw256
    x86_avx10_vmovrsw512,                      // llvm.x86.avx10.vmovrsw512
    x86_avx10_vmpsadbw_512,                    // llvm.x86.avx10.vmpsadbw.512
    x86_avx10_vmulbf16128,                     // llvm.x86.avx10.vmulbf16128
    x86_avx10_vmulbf16256,                     // llvm.x86.avx10.vmulbf16256
    x86_avx10_vmulbf16512,                     // llvm.x86.avx10.vmulbf16512
    x86_avx10_vmulpd256,                       // llvm.x86.avx10.vmulpd256
    x86_avx10_vmulph256,                       // llvm.x86.avx10.vmulph256
    x86_avx10_vmulps256,                       // llvm.x86.avx10.vmulps256
    x86_avx10_vpdpbssd_512,                    // llvm.x86.avx10.vpdpbssd.512
    x86_avx10_vpdpbssds_512,                   // llvm.x86.avx10.vpdpbssds.512
    x86_avx10_vpdpbsud_512,                    // llvm.x86.avx10.vpdpbsud.512
    x86_avx10_vpdpbsuds_512,                   // llvm.x86.avx10.vpdpbsuds.512
    x86_avx10_vpdpbuud_512,                    // llvm.x86.avx10.vpdpbuud.512
    x86_avx10_vpdpbuuds_512,                   // llvm.x86.avx10.vpdpbuuds.512
    x86_avx10_vpdpwsud_512,                    // llvm.x86.avx10.vpdpwsud.512
    x86_avx10_vpdpwsuds_512,                   // llvm.x86.avx10.vpdpwsuds.512
    x86_avx10_vpdpwusd_512,                    // llvm.x86.avx10.vpdpwusd.512
    x86_avx10_vpdpwusds_512,                   // llvm.x86.avx10.vpdpwusds.512
    x86_avx10_vpdpwuud_512,                    // llvm.x86.avx10.vpdpwuud.512
    x86_avx10_vpdpwuuds_512,                   // llvm.x86.avx10.vpdpwuuds.512
    x86_avx10_vsqrtpd256,                      // llvm.x86.avx10.vsqrtpd256
    x86_avx10_vsqrtph256,                      // llvm.x86.avx10.vsqrtph256
    x86_avx10_vsqrtps256,                      // llvm.x86.avx10.vsqrtps256
    x86_avx10_vsubbf16128,                     // llvm.x86.avx10.vsubbf16128
    x86_avx10_vsubbf16256,                     // llvm.x86.avx10.vsubbf16256
    x86_avx10_vsubbf16512,                     // llvm.x86.avx10.vsubbf16512
    x86_avx10_vsubpd256,                       // llvm.x86.avx10.vsubpd256
    x86_avx10_vsubph256,                       // llvm.x86.avx10.vsubph256
    x86_avx10_vsubps256,                       // llvm.x86.avx10.vsubps256
    x86_avx2_gather_d_d,                       // llvm.x86.avx2.gather.d.d
    x86_avx2_gather_d_d_256,                   // llvm.x86.avx2.gather.d.d.256
    x86_avx2_gather_d_pd,                      // llvm.x86.avx2.gather.d.pd
    x86_avx2_gather_d_pd_256,                  // llvm.x86.avx2.gather.d.pd.256
    x86_avx2_gather_d_ps,                      // llvm.x86.avx2.gather.d.ps
    x86_avx2_gather_d_ps_256,                  // llvm.x86.avx2.gather.d.ps.256
    x86_avx2_gather_d_q,                       // llvm.x86.avx2.gather.d.q
    x86_avx2_gather_d_q_256,                   // llvm.x86.avx2.gather.d.q.256
    x86_avx2_gather_q_d,                       // llvm.x86.avx2.gather.q.d
    x86_avx2_gather_q_d_256,                   // llvm.x86.avx2.gather.q.d.256
    x86_avx2_gather_q_pd,                      // llvm.x86.avx2.gather.q.pd
    x86_avx2_gather_q_pd_256,                  // llvm.x86.avx2.gather.q.pd.256
    x86_avx2_gather_q_ps,                      // llvm.x86.avx2.gather.q.ps
    x86_avx2_gather_q_ps_256,                  // llvm.x86.avx2.gather.q.ps.256
    x86_avx2_gather_q_q,                       // llvm.x86.avx2.gather.q.q
    x86_avx2_gather_q_q_256,                   // llvm.x86.avx2.gather.q.q.256
    x86_avx2_maskload_d,                       // llvm.x86.avx2.maskload.d
    x86_avx2_maskload_d_256,                   // llvm.x86.avx2.maskload.d.256
    x86_avx2_maskload_q,                       // llvm.x86.avx2.maskload.q
    x86_avx2_maskload_q_256,                   // llvm.x86.avx2.maskload.q.256
    x86_avx2_maskstore_d,                      // llvm.x86.avx2.maskstore.d
    x86_avx2_maskstore_d_256,                  // llvm.x86.avx2.maskstore.d.256
    x86_avx2_maskstore_q,                      // llvm.x86.avx2.maskstore.q
    x86_avx2_maskstore_q_256,                  // llvm.x86.avx2.maskstore.q.256
    x86_avx2_mpsadbw,                          // llvm.x86.avx2.mpsadbw
    x86_avx2_packssdw,                         // llvm.x86.avx2.packssdw
    x86_avx2_packsswb,                         // llvm.x86.avx2.packsswb
    x86_avx2_packusdw,                         // llvm.x86.avx2.packusdw
    x86_avx2_packuswb,                         // llvm.x86.avx2.packuswb
    x86_avx2_pavg_b,                           // llvm.x86.avx2.pavg.b
    x86_avx2_pavg_w,                           // llvm.x86.avx2.pavg.w
    x86_avx2_pblendvb,                         // llvm.x86.avx2.pblendvb
    x86_avx2_permd,                            // llvm.x86.avx2.permd
    x86_avx2_permps,                           // llvm.x86.avx2.permps
    x86_avx2_phadd_d,                          // llvm.x86.avx2.phadd.d
    x86_avx2_phadd_sw,                         // llvm.x86.avx2.phadd.sw
    x86_avx2_phadd_w,                          // llvm.x86.avx2.phadd.w
    x86_avx2_phsub_d,                          // llvm.x86.avx2.phsub.d
    x86_avx2_phsub_sw,                         // llvm.x86.avx2.phsub.sw
    x86_avx2_phsub_w,                          // llvm.x86.avx2.phsub.w
    x86_avx2_pmadd_ub_sw,                      // llvm.x86.avx2.pmadd.ub.sw
    x86_avx2_pmadd_wd,                         // llvm.x86.avx2.pmadd.wd
    x86_avx2_pmovmskb,                         // llvm.x86.avx2.pmovmskb
    x86_avx2_pmul_hr_sw,                       // llvm.x86.avx2.pmul.hr.sw
    x86_avx2_pmulh_w,                          // llvm.x86.avx2.pmulh.w
    x86_avx2_pmulhu_w,                         // llvm.x86.avx2.pmulhu.w
    x86_avx2_psad_bw,                          // llvm.x86.avx2.psad.bw
    x86_avx2_pshuf_b,                          // llvm.x86.avx2.pshuf.b
    x86_avx2_psign_b,                          // llvm.x86.avx2.psign.b
    x86_avx2_psign_d,                          // llvm.x86.avx2.psign.d
    x86_avx2_psign_w,                          // llvm.x86.avx2.psign.w
    x86_avx2_psll_d,                           // llvm.x86.avx2.psll.d
    x86_avx2_psll_q,                           // llvm.x86.avx2.psll.q
    x86_avx2_psll_w,                           // llvm.x86.avx2.psll.w
    x86_avx2_pslli_d,                          // llvm.x86.avx2.pslli.d
    x86_avx2_pslli_q,                          // llvm.x86.avx2.pslli.q
    x86_avx2_pslli_w,                          // llvm.x86.avx2.pslli.w
    x86_avx2_psllv_d,                          // llvm.x86.avx2.psllv.d
    x86_avx2_psllv_d_256,                      // llvm.x86.avx2.psllv.d.256
    x86_avx2_psllv_q,                          // llvm.x86.avx2.psllv.q
    x86_avx2_psllv_q_256,                      // llvm.x86.avx2.psllv.q.256
    x86_avx2_psra_d,                           // llvm.x86.avx2.psra.d
    x86_avx2_psra_w,                           // llvm.x86.avx2.psra.w
    x86_avx2_psrai_d,                          // llvm.x86.avx2.psrai.d
    x86_avx2_psrai_w,                          // llvm.x86.avx2.psrai.w
    x86_avx2_psrav_d,                          // llvm.x86.avx2.psrav.d
    x86_avx2_psrav_d_256,                      // llvm.x86.avx2.psrav.d.256
    x86_avx2_psrl_d,                           // llvm.x86.avx2.psrl.d
    x86_avx2_psrl_q,                           // llvm.x86.avx2.psrl.q
    x86_avx2_psrl_w,                           // llvm.x86.avx2.psrl.w
    x86_avx2_psrli_d,                          // llvm.x86.avx2.psrli.d
    x86_avx2_psrli_q,                          // llvm.x86.avx2.psrli.q
    x86_avx2_psrli_w,                          // llvm.x86.avx2.psrli.w
    x86_avx2_psrlv_d,                          // llvm.x86.avx2.psrlv.d
    x86_avx2_psrlv_d_256,                      // llvm.x86.avx2.psrlv.d.256
    x86_avx2_psrlv_q,                          // llvm.x86.avx2.psrlv.q
    x86_avx2_psrlv_q_256,                      // llvm.x86.avx2.psrlv.q.256
    x86_avx2_vpdpbssd_128,                     // llvm.x86.avx2.vpdpbssd.128
    x86_avx2_vpdpbssd_256,                     // llvm.x86.avx2.vpdpbssd.256
    x86_avx2_vpdpbssds_128,                    // llvm.x86.avx2.vpdpbssds.128
    x86_avx2_vpdpbssds_256,                    // llvm.x86.avx2.vpdpbssds.256
    x86_avx2_vpdpbsud_128,                     // llvm.x86.avx2.vpdpbsud.128
    x86_avx2_vpdpbsud_256,                     // llvm.x86.avx2.vpdpbsud.256
    x86_avx2_vpdpbsuds_128,                    // llvm.x86.avx2.vpdpbsuds.128
    x86_avx2_vpdpbsuds_256,                    // llvm.x86.avx2.vpdpbsuds.256
    x86_avx2_vpdpbuud_128,                     // llvm.x86.avx2.vpdpbuud.128
    x86_avx2_vpdpbuud_256,                     // llvm.x86.avx2.vpdpbuud.256
    x86_avx2_vpdpbuuds_128,                    // llvm.x86.avx2.vpdpbuuds.128
    x86_avx2_vpdpbuuds_256,                    // llvm.x86.avx2.vpdpbuuds.256
    x86_avx2_vpdpwsud_128,                     // llvm.x86.avx2.vpdpwsud.128
    x86_avx2_vpdpwsud_256,                     // llvm.x86.avx2.vpdpwsud.256
    x86_avx2_vpdpwsuds_128,                    // llvm.x86.avx2.vpdpwsuds.128
    x86_avx2_vpdpwsuds_256,                    // llvm.x86.avx2.vpdpwsuds.256
    x86_avx2_vpdpwusd_128,                     // llvm.x86.avx2.vpdpwusd.128
    x86_avx2_vpdpwusd_256,                     // llvm.x86.avx2.vpdpwusd.256
    x86_avx2_vpdpwusds_128,                    // llvm.x86.avx2.vpdpwusds.128
    x86_avx2_vpdpwusds_256,                    // llvm.x86.avx2.vpdpwusds.256
    x86_avx2_vpdpwuud_128,                     // llvm.x86.avx2.vpdpwuud.128
    x86_avx2_vpdpwuud_256,                     // llvm.x86.avx2.vpdpwuud.256
    x86_avx2_vpdpwuuds_128,                    // llvm.x86.avx2.vpdpwuuds.128
    x86_avx2_vpdpwuuds_256,                    // llvm.x86.avx2.vpdpwuuds.256
    x86_avx512_add_pd_512,                     // llvm.x86.avx512.add.pd.512
    x86_avx512_add_ps_512,                     // llvm.x86.avx512.add.ps.512
    x86_avx512_broadcastmb_128,                // llvm.x86.avx512.broadcastmb.128
    x86_avx512_broadcastmb_256,                // llvm.x86.avx512.broadcastmb.256
    x86_avx512_broadcastmb_512,                // llvm.x86.avx512.broadcastmb.512
    x86_avx512_broadcastmw_128,                // llvm.x86.avx512.broadcastmw.128
    x86_avx512_broadcastmw_256,                // llvm.x86.avx512.broadcastmw.256
    x86_avx512_broadcastmw_512,                // llvm.x86.avx512.broadcastmw.512
    x86_avx512_conflict_d_128,                 // llvm.x86.avx512.conflict.d.128
    x86_avx512_conflict_d_256,                 // llvm.x86.avx512.conflict.d.256
    x86_avx512_conflict_d_512,                 // llvm.x86.avx512.conflict.d.512
    x86_avx512_conflict_q_128,                 // llvm.x86.avx512.conflict.q.128
    x86_avx512_conflict_q_256,                 // llvm.x86.avx512.conflict.q.256
    x86_avx512_conflict_q_512,                 // llvm.x86.avx512.conflict.q.512
    x86_avx512_cvtsi2sd64,                     // llvm.x86.avx512.cvtsi2sd64
    x86_avx512_cvtsi2ss32,                     // llvm.x86.avx512.cvtsi2ss32
    x86_avx512_cvtsi2ss64,                     // llvm.x86.avx512.cvtsi2ss64
    x86_avx512_cvttsd2si,                      // llvm.x86.avx512.cvttsd2si
    x86_avx512_cvttsd2si64,                    // llvm.x86.avx512.cvttsd2si64
    x86_avx512_cvttsd2usi,                     // llvm.x86.avx512.cvttsd2usi
    x86_avx512_cvttsd2usi64,                   // llvm.x86.avx512.cvttsd2usi64
    x86_avx512_cvttss2si,                      // llvm.x86.avx512.cvttss2si
    x86_avx512_cvttss2si64,                    // llvm.x86.avx512.cvttss2si64
    x86_avx512_cvttss2usi,                     // llvm.x86.avx512.cvttss2usi
    x86_avx512_cvttss2usi64,                   // llvm.x86.avx512.cvttss2usi64
    x86_avx512_cvtusi2ss,                      // llvm.x86.avx512.cvtusi2ss
    x86_avx512_cvtusi642sd,                    // llvm.x86.avx512.cvtusi642sd
    x86_avx512_cvtusi642ss,                    // llvm.x86.avx512.cvtusi642ss
    x86_avx512_dbpsadbw_128,                   // llvm.x86.avx512.dbpsadbw.128
    x86_avx512_dbpsadbw_256,                   // llvm.x86.avx512.dbpsadbw.256
    x86_avx512_dbpsadbw_512,                   // llvm.x86.avx512.dbpsadbw.512
    x86_avx512_div_pd_512,                     // llvm.x86.avx512.div.pd.512
    x86_avx512_div_ps_512,                     // llvm.x86.avx512.div.ps.512
    x86_avx512_fpclass_pd_128,                 // llvm.x86.avx512.fpclass.pd.128
    x86_avx512_fpclass_pd_256,                 // llvm.x86.avx512.fpclass.pd.256
    x86_avx512_fpclass_pd_512,                 // llvm.x86.avx512.fpclass.pd.512
    x86_avx512_fpclass_ps_128,                 // llvm.x86.avx512.fpclass.ps.128
    x86_avx512_fpclass_ps_256,                 // llvm.x86.avx512.fpclass.ps.256
    x86_avx512_fpclass_ps_512,                 // llvm.x86.avx512.fpclass.ps.512
    x86_avx512_gather_dpd_512,                 // llvm.x86.avx512.gather.dpd.512
    x86_avx512_gather_dpi_512,                 // llvm.x86.avx512.gather.dpi.512
    x86_avx512_gather_dpq_512,                 // llvm.x86.avx512.gather.dpq.512
    x86_avx512_gather_dps_512,                 // llvm.x86.avx512.gather.dps.512
    x86_avx512_gather_qpd_512,                 // llvm.x86.avx512.gather.qpd.512
    x86_avx512_gather_qpi_512,                 // llvm.x86.avx512.gather.qpi.512
    x86_avx512_gather_qpq_512,                 // llvm.x86.avx512.gather.qpq.512
    x86_avx512_gather_qps_512,                 // llvm.x86.avx512.gather.qps.512
    x86_avx512_gather3div2_df,                 // llvm.x86.avx512.gather3div2.df
    x86_avx512_gather3div2_di,                 // llvm.x86.avx512.gather3div2.di
    x86_avx512_gather3div4_df,                 // llvm.x86.avx512.gather3div4.df
    x86_avx512_gather3div4_di,                 // llvm.x86.avx512.gather3div4.di
    x86_avx512_gather3div4_sf,                 // llvm.x86.avx512.gather3div4.sf
    x86_avx512_gather3div4_si,                 // llvm.x86.avx512.gather3div4.si
    x86_avx512_gather3div8_sf,                 // llvm.x86.avx512.gather3div8.sf
    x86_avx512_gather3div8_si,                 // llvm.x86.avx512.gather3div8.si
    x86_avx512_gather3siv2_df,                 // llvm.x86.avx512.gather3siv2.df
    x86_avx512_gather3siv2_di,                 // llvm.x86.avx512.gather3siv2.di
    x86_avx512_gather3siv4_df,                 // llvm.x86.avx512.gather3siv4.df
    x86_avx512_gather3siv4_di,                 // llvm.x86.avx512.gather3siv4.di
    x86_avx512_gather3siv4_sf,                 // llvm.x86.avx512.gather3siv4.sf
    x86_avx512_gather3siv4_si,                 // llvm.x86.avx512.gather3siv4.si
    x86_avx512_gather3siv8_sf,                 // llvm.x86.avx512.gather3siv8.sf
    x86_avx512_gather3siv8_si,                 // llvm.x86.avx512.gather3siv8.si
    x86_avx512_kadd_b,                         // llvm.x86.avx512.kadd.b
    x86_avx512_kadd_d,                         // llvm.x86.avx512.kadd.d
    x86_avx512_kadd_q,                         // llvm.x86.avx512.kadd.q
    x86_avx512_kadd_w,                         // llvm.x86.avx512.kadd.w
    x86_avx512_ktestc_b,                       // llvm.x86.avx512.ktestc.b
    x86_avx512_ktestc_d,                       // llvm.x86.avx512.ktestc.d
    x86_avx512_ktestc_q,                       // llvm.x86.avx512.ktestc.q
    x86_avx512_ktestc_w,                       // llvm.x86.avx512.ktestc.w
    x86_avx512_ktestz_b,                       // llvm.x86.avx512.ktestz.b
    x86_avx512_ktestz_d,                       // llvm.x86.avx512.ktestz.d
    x86_avx512_ktestz_q,                       // llvm.x86.avx512.ktestz.q
    x86_avx512_ktestz_w,                       // llvm.x86.avx512.ktestz.w
    x86_avx512_mask_add_sd_round,              // llvm.x86.avx512.mask.add.sd.round
    x86_avx512_mask_add_ss_round,              // llvm.x86.avx512.mask.add.ss.round
    x86_avx512_mask_cmp_pd_128,                // llvm.x86.avx512.mask.cmp.pd.128
    x86_avx512_mask_cmp_pd_256,                // llvm.x86.avx512.mask.cmp.pd.256
    x86_avx512_mask_cmp_pd_512,                // llvm.x86.avx512.mask.cmp.pd.512
    x86_avx512_mask_cmp_ps_128,                // llvm.x86.avx512.mask.cmp.ps.128
    x86_avx512_mask_cmp_ps_256,                // llvm.x86.avx512.mask.cmp.ps.256
    x86_avx512_mask_cmp_ps_512,                // llvm.x86.avx512.mask.cmp.ps.512
    x86_avx512_mask_cmp_sd,                    // llvm.x86.avx512.mask.cmp.sd
    x86_avx512_mask_cmp_ss,                    // llvm.x86.avx512.mask.cmp.ss
    x86_avx512_mask_compress,                  // llvm.x86.avx512.mask.compress
    x86_avx512_mask_cvtpd2dq_128,              // llvm.x86.avx512.mask.cvtpd2dq.128
    x86_avx512_mask_cvtpd2dq_512,              // llvm.x86.avx512.mask.cvtpd2dq.512
    x86_avx512_mask_cvtpd2ps,                  // llvm.x86.avx512.mask.cvtpd2ps
    x86_avx512_mask_cvtpd2ps_512,              // llvm.x86.avx512.mask.cvtpd2ps.512
    x86_avx512_mask_cvtpd2qq_128,              // llvm.x86.avx512.mask.cvtpd2qq.128
    x86_avx512_mask_cvtpd2qq_256,              // llvm.x86.avx512.mask.cvtpd2qq.256
    x86_avx512_mask_cvtpd2qq_512,              // llvm.x86.avx512.mask.cvtpd2qq.512
    x86_avx512_mask_cvtpd2udq_128,             // llvm.x86.avx512.mask.cvtpd2udq.128
    x86_avx512_mask_cvtpd2udq_256,             // llvm.x86.avx512.mask.cvtpd2udq.256
    x86_avx512_mask_cvtpd2udq_512,             // llvm.x86.avx512.mask.cvtpd2udq.512
    x86_avx512_mask_cvtpd2uqq_128,             // llvm.x86.avx512.mask.cvtpd2uqq.128
    x86_avx512_mask_cvtpd2uqq_256,             // llvm.x86.avx512.mask.cvtpd2uqq.256
    x86_avx512_mask_cvtpd2uqq_512,             // llvm.x86.avx512.mask.cvtpd2uqq.512
    x86_avx512_mask_cvtps2dq_128,              // llvm.x86.avx512.mask.cvtps2dq.128
    x86_avx512_mask_cvtps2dq_256,              // llvm.x86.avx512.mask.cvtps2dq.256
    x86_avx512_mask_cvtps2dq_512,              // llvm.x86.avx512.mask.cvtps2dq.512
    x86_avx512_mask_cvtps2pd_512,              // llvm.x86.avx512.mask.cvtps2pd.512
    x86_avx512_mask_cvtps2qq_128,              // llvm.x86.avx512.mask.cvtps2qq.128
    x86_avx512_mask_cvtps2qq_256,              // llvm.x86.avx512.mask.cvtps2qq.256
    x86_avx512_mask_cvtps2qq_512,              // llvm.x86.avx512.mask.cvtps2qq.512
    x86_avx512_mask_cvtps2udq_128,             // llvm.x86.avx512.mask.cvtps2udq.128
    x86_avx512_mask_cvtps2udq_256,             // llvm.x86.avx512.mask.cvtps2udq.256
    x86_avx512_mask_cvtps2udq_512,             // llvm.x86.avx512.mask.cvtps2udq.512
    x86_avx512_mask_cvtps2uqq_128,             // llvm.x86.avx512.mask.cvtps2uqq.128
    x86_avx512_mask_cvtps2uqq_256,             // llvm.x86.avx512.mask.cvtps2uqq.256
    x86_avx512_mask_cvtps2uqq_512,             // llvm.x86.avx512.mask.cvtps2uqq.512
    x86_avx512_mask_cvtqq2ps_128,              // llvm.x86.avx512.mask.cvtqq2ps.128
    x86_avx512_mask_cvtsd2ss_round,            // llvm.x86.avx512.mask.cvtsd2ss.round
    x86_avx512_mask_cvtss2sd_round,            // llvm.x86.avx512.mask.cvtss2sd.round
    x86_avx512_mask_cvttpd2dq_128,             // llvm.x86.avx512.mask.cvttpd2dq.128
    x86_avx512_mask_cvttpd2dq_512,             // llvm.x86.avx512.mask.cvttpd2dq.512
    x86_avx512_mask_cvttpd2qq_128,             // llvm.x86.avx512.mask.cvttpd2qq.128
    x86_avx512_mask_cvttpd2qq_256,             // llvm.x86.avx512.mask.cvttpd2qq.256
    x86_avx512_mask_cvttpd2qq_512,             // llvm.x86.avx512.mask.cvttpd2qq.512
    x86_avx512_mask_cvttpd2udq_128,            // llvm.x86.avx512.mask.cvttpd2udq.128
    x86_avx512_mask_cvttpd2udq_256,            // llvm.x86.avx512.mask.cvttpd2udq.256
    x86_avx512_mask_cvttpd2udq_512,            // llvm.x86.avx512.mask.cvttpd2udq.512
    x86_avx512_mask_cvttpd2uqq_128,            // llvm.x86.avx512.mask.cvttpd2uqq.128
    x86_avx512_mask_cvttpd2uqq_256,            // llvm.x86.avx512.mask.cvttpd2uqq.256
    x86_avx512_mask_cvttpd2uqq_512,            // llvm.x86.avx512.mask.cvttpd2uqq.512
    x86_avx512_mask_cvttps2dq_512,             // llvm.x86.avx512.mask.cvttps2dq.512
    x86_avx512_mask_cvttps2qq_128,             // llvm.x86.avx512.mask.cvttps2qq.128
    x86_avx512_mask_cvttps2qq_256,             // llvm.x86.avx512.mask.cvttps2qq.256
    x86_avx512_mask_cvttps2qq_512,             // llvm.x86.avx512.mask.cvttps2qq.512
    x86_avx512_mask_cvttps2udq_128,            // llvm.x86.avx512.mask.cvttps2udq.128
    x86_avx512_mask_cvttps2udq_256,            // llvm.x86.avx512.mask.cvttps2udq.256
    x86_avx512_mask_cvttps2udq_512,            // llvm.x86.avx512.mask.cvttps2udq.512
    x86_avx512_mask_cvttps2uqq_128,            // llvm.x86.avx512.mask.cvttps2uqq.128
    x86_avx512_mask_cvttps2uqq_256,            // llvm.x86.avx512.mask.cvttps2uqq.256
    x86_avx512_mask_cvttps2uqq_512,            // llvm.x86.avx512.mask.cvttps2uqq.512
    x86_avx512_mask_cvtuqq2ps_128,             // llvm.x86.avx512.mask.cvtuqq2ps.128
    x86_avx512_mask_div_sd_round,              // llvm.x86.avx512.mask.div.sd.round
    x86_avx512_mask_div_ss_round,              // llvm.x86.avx512.mask.div.ss.round
    x86_avx512_mask_expand,                    // llvm.x86.avx512.mask.expand
    x86_avx512_mask_fixupimm_pd_128,           // llvm.x86.avx512.mask.fixupimm.pd.128
    x86_avx512_mask_fixupimm_pd_256,           // llvm.x86.avx512.mask.fixupimm.pd.256
    x86_avx512_mask_fixupimm_pd_512,           // llvm.x86.avx512.mask.fixupimm.pd.512
    x86_avx512_mask_fixupimm_ps_128,           // llvm.x86.avx512.mask.fixupimm.ps.128
    x86_avx512_mask_fixupimm_ps_256,           // llvm.x86.avx512.mask.fixupimm.ps.256
    x86_avx512_mask_fixupimm_ps_512,           // llvm.x86.avx512.mask.fixupimm.ps.512
    x86_avx512_mask_fixupimm_sd,               // llvm.x86.avx512.mask.fixupimm.sd
    x86_avx512_mask_fixupimm_ss,               // llvm.x86.avx512.mask.fixupimm.ss
    x86_avx512_mask_fpclass_sd,                // llvm.x86.avx512.mask.fpclass.sd
    x86_avx512_mask_fpclass_ss,                // llvm.x86.avx512.mask.fpclass.ss
    x86_avx512_mask_gather_dpd_512,            // llvm.x86.avx512.mask.gather.dpd.512
    x86_avx512_mask_gather_dpi_512,            // llvm.x86.avx512.mask.gather.dpi.512
    x86_avx512_mask_gather_dpq_512,            // llvm.x86.avx512.mask.gather.dpq.512
    x86_avx512_mask_gather_dps_512,            // llvm.x86.avx512.mask.gather.dps.512
    x86_avx512_mask_gather_qpd_512,            // llvm.x86.avx512.mask.gather.qpd.512
    x86_avx512_mask_gather_qpi_512,            // llvm.x86.avx512.mask.gather.qpi.512
    x86_avx512_mask_gather_qpq_512,            // llvm.x86.avx512.mask.gather.qpq.512
    x86_avx512_mask_gather_qps_512,            // llvm.x86.avx512.mask.gather.qps.512
    x86_avx512_mask_gather3div2_df,            // llvm.x86.avx512.mask.gather3div2.df
    x86_avx512_mask_gather3div2_di,            // llvm.x86.avx512.mask.gather3div2.di
    x86_avx512_mask_gather3div4_df,            // llvm.x86.avx512.mask.gather3div4.df
    x86_avx512_mask_gather3div4_di,            // llvm.x86.avx512.mask.gather3div4.di
    x86_avx512_mask_gather3div4_sf,            // llvm.x86.avx512.mask.gather3div4.sf
    x86_avx512_mask_gather3div4_si,            // llvm.x86.avx512.mask.gather3div4.si
    x86_avx512_mask_gather3div8_sf,            // llvm.x86.avx512.mask.gather3div8.sf
    x86_avx512_mask_gather3div8_si,            // llvm.x86.avx512.mask.gather3div8.si
    x86_avx512_mask_gather3siv2_df,            // llvm.x86.avx512.mask.gather3siv2.df
    x86_avx512_mask_gather3siv2_di,            // llvm.x86.avx512.mask.gather3siv2.di
    x86_avx512_mask_gather3siv4_df,            // llvm.x86.avx512.mask.gather3siv4.df
    x86_avx512_mask_gather3siv4_di,            // llvm.x86.avx512.mask.gather3siv4.di
    x86_avx512_mask_gather3siv4_sf,            // llvm.x86.avx512.mask.gather3siv4.sf
    x86_avx512_mask_gather3siv4_si,            // llvm.x86.avx512.mask.gather3siv4.si
    x86_avx512_mask_gather3siv8_sf,            // llvm.x86.avx512.mask.gather3siv8.sf
    x86_avx512_mask_gather3siv8_si,            // llvm.x86.avx512.mask.gather3siv8.si
    x86_avx512_mask_getexp_pd_128,             // llvm.x86.avx512.mask.getexp.pd.128
    x86_avx512_mask_getexp_pd_256,             // llvm.x86.avx512.mask.getexp.pd.256
    x86_avx512_mask_getexp_pd_512,             // llvm.x86.avx512.mask.getexp.pd.512
    x86_avx512_mask_getexp_ps_128,             // llvm.x86.avx512.mask.getexp.ps.128
    x86_avx512_mask_getexp_ps_256,             // llvm.x86.avx512.mask.getexp.ps.256
    x86_avx512_mask_getexp_ps_512,             // llvm.x86.avx512.mask.getexp.ps.512
    x86_avx512_mask_getexp_sd,                 // llvm.x86.avx512.mask.getexp.sd
    x86_avx512_mask_getexp_ss,                 // llvm.x86.avx512.mask.getexp.ss
    x86_avx512_mask_getmant_pd_128,            // llvm.x86.avx512.mask.getmant.pd.128
    x86_avx512_mask_getmant_pd_256,            // llvm.x86.avx512.mask.getmant.pd.256
    x86_avx512_mask_getmant_pd_512,            // llvm.x86.avx512.mask.getmant.pd.512
    x86_avx512_mask_getmant_ps_128,            // llvm.x86.avx512.mask.getmant.ps.128
    x86_avx512_mask_getmant_ps_256,            // llvm.x86.avx512.mask.getmant.ps.256
    x86_avx512_mask_getmant_ps_512,            // llvm.x86.avx512.mask.getmant.ps.512
    x86_avx512_mask_getmant_sd,                // llvm.x86.avx512.mask.getmant.sd
    x86_avx512_mask_getmant_ss,                // llvm.x86.avx512.mask.getmant.ss
    x86_avx512_mask_max_sd_round,              // llvm.x86.avx512.mask.max.sd.round
    x86_avx512_mask_max_ss_round,              // llvm.x86.avx512.mask.max.ss.round
    x86_avx512_mask_min_sd_round,              // llvm.x86.avx512.mask.min.sd.round
    x86_avx512_mask_min_ss_round,              // llvm.x86.avx512.mask.min.ss.round
    x86_avx512_mask_mul_sd_round,              // llvm.x86.avx512.mask.mul.sd.round
    x86_avx512_mask_mul_ss_round,              // llvm.x86.avx512.mask.mul.ss.round
    x86_avx512_mask_pmov_db_128,               // llvm.x86.avx512.mask.pmov.db.128
    x86_avx512_mask_pmov_db_256,               // llvm.x86.avx512.mask.pmov.db.256
    x86_avx512_mask_pmov_db_512,               // llvm.x86.avx512.mask.pmov.db.512
    x86_avx512_mask_pmov_db_mem_128,           // llvm.x86.avx512.mask.pmov.db.mem.128
    x86_avx512_mask_pmov_db_mem_256,           // llvm.x86.avx512.mask.pmov.db.mem.256
    x86_avx512_mask_pmov_db_mem_512,           // llvm.x86.avx512.mask.pmov.db.mem.512
    x86_avx512_mask_pmov_dw_128,               // llvm.x86.avx512.mask.pmov.dw.128
    x86_avx512_mask_pmov_dw_256,               // llvm.x86.avx512.mask.pmov.dw.256
    x86_avx512_mask_pmov_dw_512,               // llvm.x86.avx512.mask.pmov.dw.512
    x86_avx512_mask_pmov_dw_mem_128,           // llvm.x86.avx512.mask.pmov.dw.mem.128
    x86_avx512_mask_pmov_dw_mem_256,           // llvm.x86.avx512.mask.pmov.dw.mem.256
    x86_avx512_mask_pmov_dw_mem_512,           // llvm.x86.avx512.mask.pmov.dw.mem.512
    x86_avx512_mask_pmov_qb_128,               // llvm.x86.avx512.mask.pmov.qb.128
    x86_avx512_mask_pmov_qb_256,               // llvm.x86.avx512.mask.pmov.qb.256
    x86_avx512_mask_pmov_qb_512,               // llvm.x86.avx512.mask.pmov.qb.512
    x86_avx512_mask_pmov_qb_mem_128,           // llvm.x86.avx512.mask.pmov.qb.mem.128
    x86_avx512_mask_pmov_qb_mem_256,           // llvm.x86.avx512.mask.pmov.qb.mem.256
    x86_avx512_mask_pmov_qb_mem_512,           // llvm.x86.avx512.mask.pmov.qb.mem.512
    x86_avx512_mask_pmov_qd_128,               // llvm.x86.avx512.mask.pmov.qd.128
    x86_avx512_mask_pmov_qd_mem_128,           // llvm.x86.avx512.mask.pmov.qd.mem.128
    x86_avx512_mask_pmov_qd_mem_256,           // llvm.x86.avx512.mask.pmov.qd.mem.256
    x86_avx512_mask_pmov_qd_mem_512,           // llvm.x86.avx512.mask.pmov.qd.mem.512
    x86_avx512_mask_pmov_qw_128,               // llvm.x86.avx512.mask.pmov.qw.128
    x86_avx512_mask_pmov_qw_256,               // llvm.x86.avx512.mask.pmov.qw.256
    x86_avx512_mask_pmov_qw_512,               // llvm.x86.avx512.mask.pmov.qw.512
    x86_avx512_mask_pmov_qw_mem_128,           // llvm.x86.avx512.mask.pmov.qw.mem.128
    x86_avx512_mask_pmov_qw_mem_256,           // llvm.x86.avx512.mask.pmov.qw.mem.256
    x86_avx512_mask_pmov_qw_mem_512,           // llvm.x86.avx512.mask.pmov.qw.mem.512
    x86_avx512_mask_pmov_wb_128,               // llvm.x86.avx512.mask.pmov.wb.128
    x86_avx512_mask_pmov_wb_mem_128,           // llvm.x86.avx512.mask.pmov.wb.mem.128
    x86_avx512_mask_pmov_wb_mem_256,           // llvm.x86.avx512.mask.pmov.wb.mem.256
    x86_avx512_mask_pmov_wb_mem_512,           // llvm.x86.avx512.mask.pmov.wb.mem.512
    x86_avx512_mask_pmovs_db_128,              // llvm.x86.avx512.mask.pmovs.db.128
    x86_avx512_mask_pmovs_db_256,              // llvm.x86.avx512.mask.pmovs.db.256
    x86_avx512_mask_pmovs_db_512,              // llvm.x86.avx512.mask.pmovs.db.512
    x86_avx512_mask_pmovs_db_mem_128,          // llvm.x86.avx512.mask.pmovs.db.mem.128
    x86_avx512_mask_pmovs_db_mem_256,          // llvm.x86.avx512.mask.pmovs.db.mem.256
    x86_avx512_mask_pmovs_db_mem_512,          // llvm.x86.avx512.mask.pmovs.db.mem.512
    x86_avx512_mask_pmovs_dw_128,              // llvm.x86.avx512.mask.pmovs.dw.128
    x86_avx512_mask_pmovs_dw_256,              // llvm.x86.avx512.mask.pmovs.dw.256
    x86_avx512_mask_pmovs_dw_512,              // llvm.x86.avx512.mask.pmovs.dw.512
    x86_avx512_mask_pmovs_dw_mem_128,          // llvm.x86.avx512.mask.pmovs.dw.mem.128
    x86_avx512_mask_pmovs_dw_mem_256,          // llvm.x86.avx512.mask.pmovs.dw.mem.256
    x86_avx512_mask_pmovs_dw_mem_512,          // llvm.x86.avx512.mask.pmovs.dw.mem.512
    x86_avx512_mask_pmovs_qb_128,              // llvm.x86.avx512.mask.pmovs.qb.128
    x86_avx512_mask_pmovs_qb_256,              // llvm.x86.avx512.mask.pmovs.qb.256
    x86_avx512_mask_pmovs_qb_512,              // llvm.x86.avx512.mask.pmovs.qb.512
    x86_avx512_mask_pmovs_qb_mem_128,          // llvm.x86.avx512.mask.pmovs.qb.mem.128
    x86_avx512_mask_pmovs_qb_mem_256,          // llvm.x86.avx512.mask.pmovs.qb.mem.256
    x86_avx512_mask_pmovs_qb_mem_512,          // llvm.x86.avx512.mask.pmovs.qb.mem.512
    x86_avx512_mask_pmovs_qd_128,              // llvm.x86.avx512.mask.pmovs.qd.128
    x86_avx512_mask_pmovs_qd_256,              // llvm.x86.avx512.mask.pmovs.qd.256
    x86_avx512_mask_pmovs_qd_512,              // llvm.x86.avx512.mask.pmovs.qd.512
    x86_avx512_mask_pmovs_qd_mem_128,          // llvm.x86.avx512.mask.pmovs.qd.mem.128
    x86_avx512_mask_pmovs_qd_mem_256,          // llvm.x86.avx512.mask.pmovs.qd.mem.256
    x86_avx512_mask_pmovs_qd_mem_512,          // llvm.x86.avx512.mask.pmovs.qd.mem.512
    x86_avx512_mask_pmovs_qw_128,              // llvm.x86.avx512.mask.pmovs.qw.128
    x86_avx512_mask_pmovs_qw_256,              // llvm.x86.avx512.mask.pmovs.qw.256
    x86_avx512_mask_pmovs_qw_512,              // llvm.x86.avx512.mask.pmovs.qw.512
    x86_avx512_mask_pmovs_qw_mem_128,          // llvm.x86.avx512.mask.pmovs.qw.mem.128
    x86_avx512_mask_pmovs_qw_mem_256,          // llvm.x86.avx512.mask.pmovs.qw.mem.256
    x86_avx512_mask_pmovs_qw_mem_512,          // llvm.x86.avx512.mask.pmovs.qw.mem.512
    x86_avx512_mask_pmovs_wb_128,              // llvm.x86.avx512.mask.pmovs.wb.128
    x86_avx512_mask_pmovs_wb_256,              // llvm.x86.avx512.mask.pmovs.wb.256
    x86_avx512_mask_pmovs_wb_512,              // llvm.x86.avx512.mask.pmovs.wb.512
    x86_avx512_mask_pmovs_wb_mem_128,          // llvm.x86.avx512.mask.pmovs.wb.mem.128
    x86_avx512_mask_pmovs_wb_mem_256,          // llvm.x86.avx512.mask.pmovs.wb.mem.256
    x86_avx512_mask_pmovs_wb_mem_512,          // llvm.x86.avx512.mask.pmovs.wb.mem.512
    x86_avx512_mask_pmovus_db_128,             // llvm.x86.avx512.mask.pmovus.db.128
    x86_avx512_mask_pmovus_db_256,             // llvm.x86.avx512.mask.pmovus.db.256
    x86_avx512_mask_pmovus_db_512,             // llvm.x86.avx512.mask.pmovus.db.512
    x86_avx512_mask_pmovus_db_mem_128,         // llvm.x86.avx512.mask.pmovus.db.mem.128
    x86_avx512_mask_pmovus_db_mem_256,         // llvm.x86.avx512.mask.pmovus.db.mem.256
    x86_avx512_mask_pmovus_db_mem_512,         // llvm.x86.avx512.mask.pmovus.db.mem.512
    x86_avx512_mask_pmovus_dw_128,             // llvm.x86.avx512.mask.pmovus.dw.128
    x86_avx512_mask_pmovus_dw_256,             // llvm.x86.avx512.mask.pmovus.dw.256
    x86_avx512_mask_pmovus_dw_512,             // llvm.x86.avx512.mask.pmovus.dw.512
    x86_avx512_mask_pmovus_dw_mem_128,         // llvm.x86.avx512.mask.pmovus.dw.mem.128
    x86_avx512_mask_pmovus_dw_mem_256,         // llvm.x86.avx512.mask.pmovus.dw.mem.256
    x86_avx512_mask_pmovus_dw_mem_512,         // llvm.x86.avx512.mask.pmovus.dw.mem.512
    x86_avx512_mask_pmovus_qb_128,             // llvm.x86.avx512.mask.pmovus.qb.128
    x86_avx512_mask_pmovus_qb_256,             // llvm.x86.avx512.mask.pmovus.qb.256
    x86_avx512_mask_pmovus_qb_512,             // llvm.x86.avx512.mask.pmovus.qb.512
    x86_avx512_mask_pmovus_qb_mem_128,         // llvm.x86.avx512.mask.pmovus.qb.mem.128
    x86_avx512_mask_pmovus_qb_mem_256,         // llvm.x86.avx512.mask.pmovus.qb.mem.256
    x86_avx512_mask_pmovus_qb_mem_512,         // llvm.x86.avx512.mask.pmovus.qb.mem.512
    x86_avx512_mask_pmovus_qd_128,             // llvm.x86.avx512.mask.pmovus.qd.128
    x86_avx512_mask_pmovus_qd_256,             // llvm.x86.avx512.mask.pmovus.qd.256
    x86_avx512_mask_pmovus_qd_512,             // llvm.x86.avx512.mask.pmovus.qd.512
    x86_avx512_mask_pmovus_qd_mem_128,         // llvm.x86.avx512.mask.pmovus.qd.mem.128
    x86_avx512_mask_pmovus_qd_mem_256,         // llvm.x86.avx512.mask.pmovus.qd.mem.256
    x86_avx512_mask_pmovus_qd_mem_512,         // llvm.x86.avx512.mask.pmovus.qd.mem.512
    x86_avx512_mask_pmovus_qw_128,             // llvm.x86.avx512.mask.pmovus.qw.128
    x86_avx512_mask_pmovus_qw_256,             // llvm.x86.avx512.mask.pmovus.qw.256
    x86_avx512_mask_pmovus_qw_512,             // llvm.x86.avx512.mask.pmovus.qw.512
    x86_avx512_mask_pmovus_qw_mem_128,         // llvm.x86.avx512.mask.pmovus.qw.mem.128
    x86_avx512_mask_pmovus_qw_mem_256,         // llvm.x86.avx512.mask.pmovus.qw.mem.256
    x86_avx512_mask_pmovus_qw_mem_512,         // llvm.x86.avx512.mask.pmovus.qw.mem.512
    x86_avx512_mask_pmovus_wb_128,             // llvm.x86.avx512.mask.pmovus.wb.128
    x86_avx512_mask_pmovus_wb_256,             // llvm.x86.avx512.mask.pmovus.wb.256
    x86_avx512_mask_pmovus_wb_512,             // llvm.x86.avx512.mask.pmovus.wb.512
    x86_avx512_mask_pmovus_wb_mem_128,         // llvm.x86.avx512.mask.pmovus.wb.mem.128
    x86_avx512_mask_pmovus_wb_mem_256,         // llvm.x86.avx512.mask.pmovus.wb.mem.256
    x86_avx512_mask_pmovus_wb_mem_512,         // llvm.x86.avx512.mask.pmovus.wb.mem.512
    x86_avx512_mask_range_pd_128,              // llvm.x86.avx512.mask.range.pd.128
    x86_avx512_mask_range_pd_256,              // llvm.x86.avx512.mask.range.pd.256
    x86_avx512_mask_range_pd_512,              // llvm.x86.avx512.mask.range.pd.512
    x86_avx512_mask_range_ps_128,              // llvm.x86.avx512.mask.range.ps.128
    x86_avx512_mask_range_ps_256,              // llvm.x86.avx512.mask.range.ps.256
    x86_avx512_mask_range_ps_512,              // llvm.x86.avx512.mask.range.ps.512
    x86_avx512_mask_range_sd,                  // llvm.x86.avx512.mask.range.sd
    x86_avx512_mask_range_ss,                  // llvm.x86.avx512.mask.range.ss
    x86_avx512_mask_reduce_pd_128,             // llvm.x86.avx512.mask.reduce.pd.128
    x86_avx512_mask_reduce_pd_256,             // llvm.x86.avx512.mask.reduce.pd.256
    x86_avx512_mask_reduce_pd_512,             // llvm.x86.avx512.mask.reduce.pd.512
    x86_avx512_mask_reduce_ps_128,             // llvm.x86.avx512.mask.reduce.ps.128
    x86_avx512_mask_reduce_ps_256,             // llvm.x86.avx512.mask.reduce.ps.256
    x86_avx512_mask_reduce_ps_512,             // llvm.x86.avx512.mask.reduce.ps.512
    x86_avx512_mask_reduce_sd,                 // llvm.x86.avx512.mask.reduce.sd
    x86_avx512_mask_reduce_ss,                 // llvm.x86.avx512.mask.reduce.ss
    x86_avx512_mask_rndscale_pd_128,           // llvm.x86.avx512.mask.rndscale.pd.128
    x86_avx512_mask_rndscale_pd_256,           // llvm.x86.avx512.mask.rndscale.pd.256
    x86_avx512_mask_rndscale_pd_512,           // llvm.x86.avx512.mask.rndscale.pd.512
    x86_avx512_mask_rndscale_ps_128,           // llvm.x86.avx512.mask.rndscale.ps.128
    x86_avx512_mask_rndscale_ps_256,           // llvm.x86.avx512.mask.rndscale.ps.256
    x86_avx512_mask_rndscale_ps_512,           // llvm.x86.avx512.mask.rndscale.ps.512
    x86_avx512_mask_rndscale_sd,               // llvm.x86.avx512.mask.rndscale.sd
    x86_avx512_mask_rndscale_ss,               // llvm.x86.avx512.mask.rndscale.ss
    x86_avx512_mask_scalef_pd_128,             // llvm.x86.avx512.mask.scalef.pd.128
    x86_avx512_mask_scalef_pd_256,             // llvm.x86.avx512.mask.scalef.pd.256
    x86_avx512_mask_scalef_pd_512,             // llvm.x86.avx512.mask.scalef.pd.512
    x86_avx512_mask_scalef_ps_128,             // llvm.x86.avx512.mask.scalef.ps.128
    x86_avx512_mask_scalef_ps_256,             // llvm.x86.avx512.mask.scalef.ps.256
    x86_avx512_mask_scalef_ps_512,             // llvm.x86.avx512.mask.scalef.ps.512
    x86_avx512_mask_scalef_sd,                 // llvm.x86.avx512.mask.scalef.sd
    x86_avx512_mask_scalef_ss,                 // llvm.x86.avx512.mask.scalef.ss
    x86_avx512_mask_scatter_dpd_512,           // llvm.x86.avx512.mask.scatter.dpd.512
    x86_avx512_mask_scatter_dpi_512,           // llvm.x86.avx512.mask.scatter.dpi.512
    x86_avx512_mask_scatter_dpq_512,           // llvm.x86.avx512.mask.scatter.dpq.512
    x86_avx512_mask_scatter_dps_512,           // llvm.x86.avx512.mask.scatter.dps.512
    x86_avx512_mask_scatter_qpd_512,           // llvm.x86.avx512.mask.scatter.qpd.512
    x86_avx512_mask_scatter_qpi_512,           // llvm.x86.avx512.mask.scatter.qpi.512
    x86_avx512_mask_scatter_qpq_512,           // llvm.x86.avx512.mask.scatter.qpq.512
    x86_avx512_mask_scatter_qps_512,           // llvm.x86.avx512.mask.scatter.qps.512
    x86_avx512_mask_scatterdiv2_df,            // llvm.x86.avx512.mask.scatterdiv2.df
    x86_avx512_mask_scatterdiv2_di,            // llvm.x86.avx512.mask.scatterdiv2.di
    x86_avx512_mask_scatterdiv4_df,            // llvm.x86.avx512.mask.scatterdiv4.df
    x86_avx512_mask_scatterdiv4_di,            // llvm.x86.avx512.mask.scatterdiv4.di
    x86_avx512_mask_scatterdiv4_sf,            // llvm.x86.avx512.mask.scatterdiv4.sf
    x86_avx512_mask_scatterdiv4_si,            // llvm.x86.avx512.mask.scatterdiv4.si
    x86_avx512_mask_scatterdiv8_sf,            // llvm.x86.avx512.mask.scatterdiv8.sf
    x86_avx512_mask_scatterdiv8_si,            // llvm.x86.avx512.mask.scatterdiv8.si
    x86_avx512_mask_scattersiv2_df,            // llvm.x86.avx512.mask.scattersiv2.df
    x86_avx512_mask_scattersiv2_di,            // llvm.x86.avx512.mask.scattersiv2.di
    x86_avx512_mask_scattersiv4_df,            // llvm.x86.avx512.mask.scattersiv4.df
    x86_avx512_mask_scattersiv4_di,            // llvm.x86.avx512.mask.scattersiv4.di
    x86_avx512_mask_scattersiv4_sf,            // llvm.x86.avx512.mask.scattersiv4.sf
    x86_avx512_mask_scattersiv4_si,            // llvm.x86.avx512.mask.scattersiv4.si
    x86_avx512_mask_scattersiv8_sf,            // llvm.x86.avx512.mask.scattersiv8.sf
    x86_avx512_mask_scattersiv8_si,            // llvm.x86.avx512.mask.scattersiv8.si
    x86_avx512_mask_sqrt_sd,                   // llvm.x86.avx512.mask.sqrt.sd
    x86_avx512_mask_sqrt_ss,                   // llvm.x86.avx512.mask.sqrt.ss
    x86_avx512_mask_sub_sd_round,              // llvm.x86.avx512.mask.sub.sd.round
    x86_avx512_mask_sub_ss_round,              // llvm.x86.avx512.mask.sub.ss.round
    x86_avx512_mask_vcvtph2ps_512,             // llvm.x86.avx512.mask.vcvtph2ps.512
    x86_avx512_mask_vcvtps2ph_128,             // llvm.x86.avx512.mask.vcvtps2ph.128
    x86_avx512_mask_vcvtps2ph_256,             // llvm.x86.avx512.mask.vcvtps2ph.256
    x86_avx512_mask_vcvtps2ph_512,             // llvm.x86.avx512.mask.vcvtps2ph.512
    x86_avx512_maskz_fixupimm_pd_128,          // llvm.x86.avx512.maskz.fixupimm.pd.128
    x86_avx512_maskz_fixupimm_pd_256,          // llvm.x86.avx512.maskz.fixupimm.pd.256
    x86_avx512_maskz_fixupimm_pd_512,          // llvm.x86.avx512.maskz.fixupimm.pd.512
    x86_avx512_maskz_fixupimm_ps_128,          // llvm.x86.avx512.maskz.fixupimm.ps.128
    x86_avx512_maskz_fixupimm_ps_256,          // llvm.x86.avx512.maskz.fixupimm.ps.256
    x86_avx512_maskz_fixupimm_ps_512,          // llvm.x86.avx512.maskz.fixupimm.ps.512
    x86_avx512_maskz_fixupimm_sd,              // llvm.x86.avx512.maskz.fixupimm.sd
    x86_avx512_maskz_fixupimm_ss,              // llvm.x86.avx512.maskz.fixupimm.ss
    x86_avx512_max_pd_512,                     // llvm.x86.avx512.max.pd.512
    x86_avx512_max_ps_512,                     // llvm.x86.avx512.max.ps.512
    x86_avx512_min_pd_512,                     // llvm.x86.avx512.min.pd.512
    x86_avx512_min_ps_512,                     // llvm.x86.avx512.min.ps.512
    x86_avx512_mul_pd_512,                     // llvm.x86.avx512.mul.pd.512
    x86_avx512_mul_ps_512,                     // llvm.x86.avx512.mul.ps.512
    x86_avx512_packssdw_512,                   // llvm.x86.avx512.packssdw.512
    x86_avx512_packsswb_512,                   // llvm.x86.avx512.packsswb.512
    x86_avx512_packusdw_512,                   // llvm.x86.avx512.packusdw.512
    x86_avx512_packuswb_512,                   // llvm.x86.avx512.packuswb.512
    x86_avx512_pavg_b_512,                     // llvm.x86.avx512.pavg.b.512
    x86_avx512_pavg_w_512,                     // llvm.x86.avx512.pavg.w.512
    x86_avx512_permvar_df_256,                 // llvm.x86.avx512.permvar.df.256
    x86_avx512_permvar_df_512,                 // llvm.x86.avx512.permvar.df.512
    x86_avx512_permvar_di_256,                 // llvm.x86.avx512.permvar.di.256
    x86_avx512_permvar_di_512,                 // llvm.x86.avx512.permvar.di.512
    x86_avx512_permvar_hi_128,                 // llvm.x86.avx512.permvar.hi.128
    x86_avx512_permvar_hi_256,                 // llvm.x86.avx512.permvar.hi.256
    x86_avx512_permvar_hi_512,                 // llvm.x86.avx512.permvar.hi.512
    x86_avx512_permvar_qi_128,                 // llvm.x86.avx512.permvar.qi.128
    x86_avx512_permvar_qi_256,                 // llvm.x86.avx512.permvar.qi.256
    x86_avx512_permvar_qi_512,                 // llvm.x86.avx512.permvar.qi.512
    x86_avx512_permvar_sf_512,                 // llvm.x86.avx512.permvar.sf.512
    x86_avx512_permvar_si_512,                 // llvm.x86.avx512.permvar.si.512
    x86_avx512_pmaddubs_w_512,                 // llvm.x86.avx512.pmaddubs.w.512
    x86_avx512_pmaddw_d_512,                   // llvm.x86.avx512.pmaddw.d.512
    x86_avx512_pmul_hr_sw_512,                 // llvm.x86.avx512.pmul.hr.sw.512
    x86_avx512_pmulh_w_512,                    // llvm.x86.avx512.pmulh.w.512
    x86_avx512_pmulhu_w_512,                   // llvm.x86.avx512.pmulhu.w.512
    x86_avx512_pmultishift_qb_128,             // llvm.x86.avx512.pmultishift.qb.128
    x86_avx512_pmultishift_qb_256,             // llvm.x86.avx512.pmultishift.qb.256
    x86_avx512_pmultishift_qb_512,             // llvm.x86.avx512.pmultishift.qb.512
    x86_avx512_psad_bw_512,                    // llvm.x86.avx512.psad.bw.512
    x86_avx512_pshuf_b_512,                    // llvm.x86.avx512.pshuf.b.512
    x86_avx512_psll_d_512,                     // llvm.x86.avx512.psll.d.512
    x86_avx512_psll_q_512,                     // llvm.x86.avx512.psll.q.512
    x86_avx512_psll_w_512,                     // llvm.x86.avx512.psll.w.512
    x86_avx512_pslli_d_512,                    // llvm.x86.avx512.pslli.d.512
    x86_avx512_pslli_q_512,                    // llvm.x86.avx512.pslli.q.512
    x86_avx512_pslli_w_512,                    // llvm.x86.avx512.pslli.w.512
    x86_avx512_psllv_d_512,                    // llvm.x86.avx512.psllv.d.512
    x86_avx512_psllv_q_512,                    // llvm.x86.avx512.psllv.q.512
    x86_avx512_psllv_w_128,                    // llvm.x86.avx512.psllv.w.128
    x86_avx512_psllv_w_256,                    // llvm.x86.avx512.psllv.w.256
    x86_avx512_psllv_w_512,                    // llvm.x86.avx512.psllv.w.512
    x86_avx512_psra_d_512,                     // llvm.x86.avx512.psra.d.512
    x86_avx512_psra_q_128,                     // llvm.x86.avx512.psra.q.128
    x86_avx512_psra_q_256,                     // llvm.x86.avx512.psra.q.256
    x86_avx512_psra_q_512,                     // llvm.x86.avx512.psra.q.512
    x86_avx512_psra_w_512,                     // llvm.x86.avx512.psra.w.512
    x86_avx512_psrai_d_512,                    // llvm.x86.avx512.psrai.d.512
    x86_avx512_psrai_q_128,                    // llvm.x86.avx512.psrai.q.128
    x86_avx512_psrai_q_256,                    // llvm.x86.avx512.psrai.q.256
    x86_avx512_psrai_q_512,                    // llvm.x86.avx512.psrai.q.512
    x86_avx512_psrai_w_512,                    // llvm.x86.avx512.psrai.w.512
    x86_avx512_psrav_d_512,                    // llvm.x86.avx512.psrav.d.512
    x86_avx512_psrav_q_128,                    // llvm.x86.avx512.psrav.q.128
    x86_avx512_psrav_q_256,                    // llvm.x86.avx512.psrav.q.256
    x86_avx512_psrav_q_512,                    // llvm.x86.avx512.psrav.q.512
    x86_avx512_psrav_w_128,                    // llvm.x86.avx512.psrav.w.128
    x86_avx512_psrav_w_256,                    // llvm.x86.avx512.psrav.w.256
    x86_avx512_psrav_w_512,                    // llvm.x86.avx512.psrav.w.512
    x86_avx512_psrl_d_512,                     // llvm.x86.avx512.psrl.d.512
    x86_avx512_psrl_q_512,                     // llvm.x86.avx512.psrl.q.512
    x86_avx512_psrl_w_512,                     // llvm.x86.avx512.psrl.w.512
    x86_avx512_psrli_d_512,                    // llvm.x86.avx512.psrli.d.512
    x86_avx512_psrli_q_512,                    // llvm.x86.avx512.psrli.q.512
    x86_avx512_psrli_w_512,                    // llvm.x86.avx512.psrli.w.512
    x86_avx512_psrlv_d_512,                    // llvm.x86.avx512.psrlv.d.512
    x86_avx512_psrlv_q_512,                    // llvm.x86.avx512.psrlv.q.512
    x86_avx512_psrlv_w_128,                    // llvm.x86.avx512.psrlv.w.128
    x86_avx512_psrlv_w_256,                    // llvm.x86.avx512.psrlv.w.256
    x86_avx512_psrlv_w_512,                    // llvm.x86.avx512.psrlv.w.512
    x86_avx512_pternlog_d_128,                 // llvm.x86.avx512.pternlog.d.128
    x86_avx512_pternlog_d_256,                 // llvm.x86.avx512.pternlog.d.256
    x86_avx512_pternlog_d_512,                 // llvm.x86.avx512.pternlog.d.512
    x86_avx512_pternlog_q_128,                 // llvm.x86.avx512.pternlog.q.128
    x86_avx512_pternlog_q_256,                 // llvm.x86.avx512.pternlog.q.256
    x86_avx512_pternlog_q_512,                 // llvm.x86.avx512.pternlog.q.512
    x86_avx512_rcp14_pd_128,                   // llvm.x86.avx512.rcp14.pd.128
    x86_avx512_rcp14_pd_256,                   // llvm.x86.avx512.rcp14.pd.256
    x86_avx512_rcp14_pd_512,                   // llvm.x86.avx512.rcp14.pd.512
    x86_avx512_rcp14_ps_128,                   // llvm.x86.avx512.rcp14.ps.128
    x86_avx512_rcp14_ps_256,                   // llvm.x86.avx512.rcp14.ps.256
    x86_avx512_rcp14_ps_512,                   // llvm.x86.avx512.rcp14.ps.512
    x86_avx512_rcp14_sd,                       // llvm.x86.avx512.rcp14.sd
    x86_avx512_rcp14_ss,                       // llvm.x86.avx512.rcp14.ss
    x86_avx512_rsqrt14_pd_128,                 // llvm.x86.avx512.rsqrt14.pd.128
    x86_avx512_rsqrt14_pd_256,                 // llvm.x86.avx512.rsqrt14.pd.256
    x86_avx512_rsqrt14_pd_512,                 // llvm.x86.avx512.rsqrt14.pd.512
    x86_avx512_rsqrt14_ps_128,                 // llvm.x86.avx512.rsqrt14.ps.128
    x86_avx512_rsqrt14_ps_256,                 // llvm.x86.avx512.rsqrt14.ps.256
    x86_avx512_rsqrt14_ps_512,                 // llvm.x86.avx512.rsqrt14.ps.512
    x86_avx512_rsqrt14_sd,                     // llvm.x86.avx512.rsqrt14.sd
    x86_avx512_rsqrt14_ss,                     // llvm.x86.avx512.rsqrt14.ss
    x86_avx512_scatter_dpd_512,                // llvm.x86.avx512.scatter.dpd.512
    x86_avx512_scatter_dpi_512,                // llvm.x86.avx512.scatter.dpi.512
    x86_avx512_scatter_dpq_512,                // llvm.x86.avx512.scatter.dpq.512
    x86_avx512_scatter_dps_512,                // llvm.x86.avx512.scatter.dps.512
    x86_avx512_scatter_qpd_512,                // llvm.x86.avx512.scatter.qpd.512
    x86_avx512_scatter_qpi_512,                // llvm.x86.avx512.scatter.qpi.512
    x86_avx512_scatter_qpq_512,                // llvm.x86.avx512.scatter.qpq.512
    x86_avx512_scatter_qps_512,                // llvm.x86.avx512.scatter.qps.512
    x86_avx512_scatterdiv2_df,                 // llvm.x86.avx512.scatterdiv2.df
    x86_avx512_scatterdiv2_di,                 // llvm.x86.avx512.scatterdiv2.di
    x86_avx512_scatterdiv4_df,                 // llvm.x86.avx512.scatterdiv4.df
    x86_avx512_scatterdiv4_di,                 // llvm.x86.avx512.scatterdiv4.di
    x86_avx512_scatterdiv4_sf,                 // llvm.x86.avx512.scatterdiv4.sf
    x86_avx512_scatterdiv4_si,                 // llvm.x86.avx512.scatterdiv4.si
    x86_avx512_scatterdiv8_sf,                 // llvm.x86.avx512.scatterdiv8.sf
    x86_avx512_scatterdiv8_si,                 // llvm.x86.avx512.scatterdiv8.si
    x86_avx512_scattersiv2_df,                 // llvm.x86.avx512.scattersiv2.df
    x86_avx512_scattersiv2_di,                 // llvm.x86.avx512.scattersiv2.di
    x86_avx512_scattersiv4_df,                 // llvm.x86.avx512.scattersiv4.df
    x86_avx512_scattersiv4_di,                 // llvm.x86.avx512.scattersiv4.di
    x86_avx512_scattersiv4_sf,                 // llvm.x86.avx512.scattersiv4.sf
    x86_avx512_scattersiv4_si,                 // llvm.x86.avx512.scattersiv4.si
    x86_avx512_scattersiv8_sf,                 // llvm.x86.avx512.scattersiv8.sf
    x86_avx512_scattersiv8_si,                 // llvm.x86.avx512.scattersiv8.si
    x86_avx512_sitofp_round,                   // llvm.x86.avx512.sitofp.round
    x86_avx512_sqrt_pd_512,                    // llvm.x86.avx512.sqrt.pd.512
    x86_avx512_sqrt_ps_512,                    // llvm.x86.avx512.sqrt.ps.512
    x86_avx512_sub_pd_512,                     // llvm.x86.avx512.sub.pd.512
    x86_avx512_sub_ps_512,                     // llvm.x86.avx512.sub.ps.512
    x86_avx512_uitofp_round,                   // llvm.x86.avx512.uitofp.round
    x86_avx512_vcomi_sd,                       // llvm.x86.avx512.vcomi.sd
    x86_avx512_vcomi_ss,                       // llvm.x86.avx512.vcomi.ss
    x86_avx512_vcvtsd2si32,                    // llvm.x86.avx512.vcvtsd2si32
    x86_avx512_vcvtsd2si64,                    // llvm.x86.avx512.vcvtsd2si64
    x86_avx512_vcvtsd2usi32,                   // llvm.x86.avx512.vcvtsd2usi32
    x86_avx512_vcvtsd2usi64,                   // llvm.x86.avx512.vcvtsd2usi64
    x86_avx512_vcvtss2si32,                    // llvm.x86.avx512.vcvtss2si32
    x86_avx512_vcvtss2si64,                    // llvm.x86.avx512.vcvtss2si64
    x86_avx512_vcvtss2usi32,                   // llvm.x86.avx512.vcvtss2usi32
    x86_avx512_vcvtss2usi64,                   // llvm.x86.avx512.vcvtss2usi64
    x86_avx512_vfmadd_f32,                     // llvm.x86.avx512.vfmadd.f32
    x86_avx512_vfmadd_f64,                     // llvm.x86.avx512.vfmadd.f64
    x86_avx512_vfmadd_pd_512,                  // llvm.x86.avx512.vfmadd.pd.512
    x86_avx512_vfmadd_ps_512,                  // llvm.x86.avx512.vfmadd.ps.512
    x86_avx512_vfmaddsub_pd_512,               // llvm.x86.avx512.vfmaddsub.pd.512
    x86_avx512_vfmaddsub_ps_512,               // llvm.x86.avx512.vfmaddsub.ps.512
    x86_avx512_vp2intersect_d_128,             // llvm.x86.avx512.vp2intersect.d.128
    x86_avx512_vp2intersect_d_256,             // llvm.x86.avx512.vp2intersect.d.256
    x86_avx512_vp2intersect_d_512,             // llvm.x86.avx512.vp2intersect.d.512
    x86_avx512_vp2intersect_q_128,             // llvm.x86.avx512.vp2intersect.q.128
    x86_avx512_vp2intersect_q_256,             // llvm.x86.avx512.vp2intersect.q.256
    x86_avx512_vp2intersect_q_512,             // llvm.x86.avx512.vp2intersect.q.512
    x86_avx512_vpdpbusd_128,                   // llvm.x86.avx512.vpdpbusd.128
    x86_avx512_vpdpbusd_256,                   // llvm.x86.avx512.vpdpbusd.256
    x86_avx512_vpdpbusd_512,                   // llvm.x86.avx512.vpdpbusd.512
    x86_avx512_vpdpbusds_128,                  // llvm.x86.avx512.vpdpbusds.128
    x86_avx512_vpdpbusds_256,                  // llvm.x86.avx512.vpdpbusds.256
    x86_avx512_vpdpbusds_512,                  // llvm.x86.avx512.vpdpbusds.512
    x86_avx512_vpdpwssd_128,                   // llvm.x86.avx512.vpdpwssd.128
    x86_avx512_vpdpwssd_256,                   // llvm.x86.avx512.vpdpwssd.256
    x86_avx512_vpdpwssd_512,                   // llvm.x86.avx512.vpdpwssd.512
    x86_avx512_vpdpwssds_128,                  // llvm.x86.avx512.vpdpwssds.128
    x86_avx512_vpdpwssds_256,                  // llvm.x86.avx512.vpdpwssds.256
    x86_avx512_vpdpwssds_512,                  // llvm.x86.avx512.vpdpwssds.512
    x86_avx512_vpermi2var_d_128,               // llvm.x86.avx512.vpermi2var.d.128
    x86_avx512_vpermi2var_d_256,               // llvm.x86.avx512.vpermi2var.d.256
    x86_avx512_vpermi2var_d_512,               // llvm.x86.avx512.vpermi2var.d.512
    x86_avx512_vpermi2var_hi_128,              // llvm.x86.avx512.vpermi2var.hi.128
    x86_avx512_vpermi2var_hi_256,              // llvm.x86.avx512.vpermi2var.hi.256
    x86_avx512_vpermi2var_hi_512,              // llvm.x86.avx512.vpermi2var.hi.512
    x86_avx512_vpermi2var_pd_128,              // llvm.x86.avx512.vpermi2var.pd.128
    x86_avx512_vpermi2var_pd_256,              // llvm.x86.avx512.vpermi2var.pd.256
    x86_avx512_vpermi2var_pd_512,              // llvm.x86.avx512.vpermi2var.pd.512
    x86_avx512_vpermi2var_ps_128,              // llvm.x86.avx512.vpermi2var.ps.128
    x86_avx512_vpermi2var_ps_256,              // llvm.x86.avx512.vpermi2var.ps.256
    x86_avx512_vpermi2var_ps_512,              // llvm.x86.avx512.vpermi2var.ps.512
    x86_avx512_vpermi2var_q_128,               // llvm.x86.avx512.vpermi2var.q.128
    x86_avx512_vpermi2var_q_256,               // llvm.x86.avx512.vpermi2var.q.256
    x86_avx512_vpermi2var_q_512,               // llvm.x86.avx512.vpermi2var.q.512
    x86_avx512_vpermi2var_qi_128,              // llvm.x86.avx512.vpermi2var.qi.128
    x86_avx512_vpermi2var_qi_256,              // llvm.x86.avx512.vpermi2var.qi.256
    x86_avx512_vpermi2var_qi_512,              // llvm.x86.avx512.vpermi2var.qi.512
    x86_avx512_vpermilvar_pd_512,              // llvm.x86.avx512.vpermilvar.pd.512
    x86_avx512_vpermilvar_ps_512,              // llvm.x86.avx512.vpermilvar.ps.512
    x86_avx512_vpmadd52h_uq_128,               // llvm.x86.avx512.vpmadd52h.uq.128
    x86_avx512_vpmadd52h_uq_256,               // llvm.x86.avx512.vpmadd52h.uq.256
    x86_avx512_vpmadd52h_uq_512,               // llvm.x86.avx512.vpmadd52h.uq.512
    x86_avx512_vpmadd52l_uq_128,               // llvm.x86.avx512.vpmadd52l.uq.128
    x86_avx512_vpmadd52l_uq_256,               // llvm.x86.avx512.vpmadd52l.uq.256
    x86_avx512_vpmadd52l_uq_512,               // llvm.x86.avx512.vpmadd52l.uq.512
    x86_avx512_vpshufbitqmb_128,               // llvm.x86.avx512.vpshufbitqmb.128
    x86_avx512_vpshufbitqmb_256,               // llvm.x86.avx512.vpshufbitqmb.256
    x86_avx512_vpshufbitqmb_512,               // llvm.x86.avx512.vpshufbitqmb.512
    x86_avx512bf16_cvtne2ps2bf16_128,          // llvm.x86.avx512bf16.cvtne2ps2bf16.128
    x86_avx512bf16_cvtne2ps2bf16_256,          // llvm.x86.avx512bf16.cvtne2ps2bf16.256
    x86_avx512bf16_cvtne2ps2bf16_512,          // llvm.x86.avx512bf16.cvtne2ps2bf16.512
    x86_avx512bf16_cvtneps2bf16_256,           // llvm.x86.avx512bf16.cvtneps2bf16.256
    x86_avx512bf16_cvtneps2bf16_512,           // llvm.x86.avx512bf16.cvtneps2bf16.512
    x86_avx512bf16_dpbf16ps_128,               // llvm.x86.avx512bf16.dpbf16ps.128
    x86_avx512bf16_dpbf16ps_256,               // llvm.x86.avx512bf16.dpbf16ps.256
    x86_avx512bf16_dpbf16ps_512,               // llvm.x86.avx512bf16.dpbf16ps.512
    x86_avx512bf16_mask_cvtneps2bf16_128,      // llvm.x86.avx512bf16.mask.cvtneps2bf16.128
    x86_avx512fp16_add_ph_512,                 // llvm.x86.avx512fp16.add.ph.512
    x86_avx512fp16_div_ph_512,                 // llvm.x86.avx512fp16.div.ph.512
    x86_avx512fp16_fpclass_ph_128,             // llvm.x86.avx512fp16.fpclass.ph.128
    x86_avx512fp16_fpclass_ph_256,             // llvm.x86.avx512fp16.fpclass.ph.256
    x86_avx512fp16_fpclass_ph_512,             // llvm.x86.avx512fp16.fpclass.ph.512
    x86_avx512fp16_mask_add_sh_round,          // llvm.x86.avx512fp16.mask.add.sh.round
    x86_avx512fp16_mask_cmp_ph_128,            // llvm.x86.avx512fp16.mask.cmp.ph.128
    x86_avx512fp16_mask_cmp_ph_256,            // llvm.x86.avx512fp16.mask.cmp.ph.256
    x86_avx512fp16_mask_cmp_ph_512,            // llvm.x86.avx512fp16.mask.cmp.ph.512
    x86_avx512fp16_mask_cmp_sh,                // llvm.x86.avx512fp16.mask.cmp.sh
    x86_avx512fp16_mask_div_sh_round,          // llvm.x86.avx512fp16.mask.div.sh.round
    x86_avx512fp16_mask_fpclass_sh,            // llvm.x86.avx512fp16.mask.fpclass.sh
    x86_avx512fp16_mask_getexp_ph_128,         // llvm.x86.avx512fp16.mask.getexp.ph.128
    x86_avx512fp16_mask_getexp_ph_256,         // llvm.x86.avx512fp16.mask.getexp.ph.256
    x86_avx512fp16_mask_getexp_ph_512,         // llvm.x86.avx512fp16.mask.getexp.ph.512
    x86_avx512fp16_mask_getexp_sh,             // llvm.x86.avx512fp16.mask.getexp.sh
    x86_avx512fp16_mask_getmant_ph_128,        // llvm.x86.avx512fp16.mask.getmant.ph.128
    x86_avx512fp16_mask_getmant_ph_256,        // llvm.x86.avx512fp16.mask.getmant.ph.256
    x86_avx512fp16_mask_getmant_ph_512,        // llvm.x86.avx512fp16.mask.getmant.ph.512
    x86_avx512fp16_mask_getmant_sh,            // llvm.x86.avx512fp16.mask.getmant.sh
    x86_avx512fp16_mask_max_sh_round,          // llvm.x86.avx512fp16.mask.max.sh.round
    x86_avx512fp16_mask_min_sh_round,          // llvm.x86.avx512fp16.mask.min.sh.round
    x86_avx512fp16_mask_mul_sh_round,          // llvm.x86.avx512fp16.mask.mul.sh.round
    x86_avx512fp16_mask_rcp_ph_128,            // llvm.x86.avx512fp16.mask.rcp.ph.128
    x86_avx512fp16_mask_rcp_ph_256,            // llvm.x86.avx512fp16.mask.rcp.ph.256
    x86_avx512fp16_mask_rcp_ph_512,            // llvm.x86.avx512fp16.mask.rcp.ph.512
    x86_avx512fp16_mask_rcp_sh,                // llvm.x86.avx512fp16.mask.rcp.sh
    x86_avx512fp16_mask_reduce_ph_128,         // llvm.x86.avx512fp16.mask.reduce.ph.128
    x86_avx512fp16_mask_reduce_ph_256,         // llvm.x86.avx512fp16.mask.reduce.ph.256
    x86_avx512fp16_mask_reduce_ph_512,         // llvm.x86.avx512fp16.mask.reduce.ph.512
    x86_avx512fp16_mask_reduce_sh,             // llvm.x86.avx512fp16.mask.reduce.sh
    x86_avx512fp16_mask_rndscale_ph_128,       // llvm.x86.avx512fp16.mask.rndscale.ph.128
    x86_avx512fp16_mask_rndscale_ph_256,       // llvm.x86.avx512fp16.mask.rndscale.ph.256
    x86_avx512fp16_mask_rndscale_ph_512,       // llvm.x86.avx512fp16.mask.rndscale.ph.512
    x86_avx512fp16_mask_rndscale_sh,           // llvm.x86.avx512fp16.mask.rndscale.sh
    x86_avx512fp16_mask_rsqrt_ph_128,          // llvm.x86.avx512fp16.mask.rsqrt.ph.128
    x86_avx512fp16_mask_rsqrt_ph_256,          // llvm.x86.avx512fp16.mask.rsqrt.ph.256
    x86_avx512fp16_mask_rsqrt_ph_512,          // llvm.x86.avx512fp16.mask.rsqrt.ph.512
    x86_avx512fp16_mask_rsqrt_sh,              // llvm.x86.avx512fp16.mask.rsqrt.sh
    x86_avx512fp16_mask_scalef_ph_128,         // llvm.x86.avx512fp16.mask.scalef.ph.128
    x86_avx512fp16_mask_scalef_ph_256,         // llvm.x86.avx512fp16.mask.scalef.ph.256
    x86_avx512fp16_mask_scalef_ph_512,         // llvm.x86.avx512fp16.mask.scalef.ph.512
    x86_avx512fp16_mask_scalef_sh,             // llvm.x86.avx512fp16.mask.scalef.sh
    x86_avx512fp16_mask_sqrt_sh,               // llvm.x86.avx512fp16.mask.sqrt.sh
    x86_avx512fp16_mask_sub_sh_round,          // llvm.x86.avx512fp16.mask.sub.sh.round
    x86_avx512fp16_mask_vcvtdq2ph_128,         // llvm.x86.avx512fp16.mask.vcvtdq2ph.128
    x86_avx512fp16_mask_vcvtpd2ph_128,         // llvm.x86.avx512fp16.mask.vcvtpd2ph.128
    x86_avx512fp16_mask_vcvtpd2ph_256,         // llvm.x86.avx512fp16.mask.vcvtpd2ph.256
    x86_avx512fp16_mask_vcvtpd2ph_512,         // llvm.x86.avx512fp16.mask.vcvtpd2ph.512
    x86_avx512fp16_mask_vcvtph2dq_128,         // llvm.x86.avx512fp16.mask.vcvtph2dq.128
    x86_avx512fp16_mask_vcvtph2dq_256,         // llvm.x86.avx512fp16.mask.vcvtph2dq.256
    x86_avx512fp16_mask_vcvtph2dq_512,         // llvm.x86.avx512fp16.mask.vcvtph2dq.512
    x86_avx512fp16_mask_vcvtph2pd_128,         // llvm.x86.avx512fp16.mask.vcvtph2pd.128
    x86_avx512fp16_mask_vcvtph2pd_256,         // llvm.x86.avx512fp16.mask.vcvtph2pd.256
    x86_avx512fp16_mask_vcvtph2pd_512,         // llvm.x86.avx512fp16.mask.vcvtph2pd.512
    x86_avx512fp16_mask_vcvtph2psx_128,        // llvm.x86.avx512fp16.mask.vcvtph2psx.128
    x86_avx512fp16_mask_vcvtph2psx_256,        // llvm.x86.avx512fp16.mask.vcvtph2psx.256
    x86_avx512fp16_mask_vcvtph2psx_512,        // llvm.x86.avx512fp16.mask.vcvtph2psx.512
    x86_avx512fp16_mask_vcvtph2qq_128,         // llvm.x86.avx512fp16.mask.vcvtph2qq.128
    x86_avx512fp16_mask_vcvtph2qq_256,         // llvm.x86.avx512fp16.mask.vcvtph2qq.256
    x86_avx512fp16_mask_vcvtph2qq_512,         // llvm.x86.avx512fp16.mask.vcvtph2qq.512
    x86_avx512fp16_mask_vcvtph2udq_128,        // llvm.x86.avx512fp16.mask.vcvtph2udq.128
    x86_avx512fp16_mask_vcvtph2udq_256,        // llvm.x86.avx512fp16.mask.vcvtph2udq.256
    x86_avx512fp16_mask_vcvtph2udq_512,        // llvm.x86.avx512fp16.mask.vcvtph2udq.512
    x86_avx512fp16_mask_vcvtph2uqq_128,        // llvm.x86.avx512fp16.mask.vcvtph2uqq.128
    x86_avx512fp16_mask_vcvtph2uqq_256,        // llvm.x86.avx512fp16.mask.vcvtph2uqq.256
    x86_avx512fp16_mask_vcvtph2uqq_512,        // llvm.x86.avx512fp16.mask.vcvtph2uqq.512
    x86_avx512fp16_mask_vcvtph2uw_128,         // llvm.x86.avx512fp16.mask.vcvtph2uw.128
    x86_avx512fp16_mask_vcvtph2uw_256,         // llvm.x86.avx512fp16.mask.vcvtph2uw.256
    x86_avx512fp16_mask_vcvtph2uw_512,         // llvm.x86.avx512fp16.mask.vcvtph2uw.512
    x86_avx512fp16_mask_vcvtph2w_128,          // llvm.x86.avx512fp16.mask.vcvtph2w.128
    x86_avx512fp16_mask_vcvtph2w_256,          // llvm.x86.avx512fp16.mask.vcvtph2w.256
    x86_avx512fp16_mask_vcvtph2w_512,          // llvm.x86.avx512fp16.mask.vcvtph2w.512
    x86_avx512fp16_mask_vcvtps2phx_128,        // llvm.x86.avx512fp16.mask.vcvtps2phx.128
    x86_avx512fp16_mask_vcvtps2phx_256,        // llvm.x86.avx512fp16.mask.vcvtps2phx.256
    x86_avx512fp16_mask_vcvtps2phx_512,        // llvm.x86.avx512fp16.mask.vcvtps2phx.512
    x86_avx512fp16_mask_vcvtqq2ph_128,         // llvm.x86.avx512fp16.mask.vcvtqq2ph.128
    x86_avx512fp16_mask_vcvtqq2ph_256,         // llvm.x86.avx512fp16.mask.vcvtqq2ph.256
    x86_avx512fp16_mask_vcvtsd2sh_round,       // llvm.x86.avx512fp16.mask.vcvtsd2sh.round
    x86_avx512fp16_mask_vcvtsh2sd_round,       // llvm.x86.avx512fp16.mask.vcvtsh2sd.round
    x86_avx512fp16_mask_vcvtsh2ss_round,       // llvm.x86.avx512fp16.mask.vcvtsh2ss.round
    x86_avx512fp16_mask_vcvtss2sh_round,       // llvm.x86.avx512fp16.mask.vcvtss2sh.round
    x86_avx512fp16_mask_vcvttph2dq_128,        // llvm.x86.avx512fp16.mask.vcvttph2dq.128
    x86_avx512fp16_mask_vcvttph2dq_256,        // llvm.x86.avx512fp16.mask.vcvttph2dq.256
    x86_avx512fp16_mask_vcvttph2dq_512,        // llvm.x86.avx512fp16.mask.vcvttph2dq.512
    x86_avx512fp16_mask_vcvttph2qq_128,        // llvm.x86.avx512fp16.mask.vcvttph2qq.128
    x86_avx512fp16_mask_vcvttph2qq_256,        // llvm.x86.avx512fp16.mask.vcvttph2qq.256
    x86_avx512fp16_mask_vcvttph2qq_512,        // llvm.x86.avx512fp16.mask.vcvttph2qq.512
    x86_avx512fp16_mask_vcvttph2udq_128,       // llvm.x86.avx512fp16.mask.vcvttph2udq.128
    x86_avx512fp16_mask_vcvttph2udq_256,       // llvm.x86.avx512fp16.mask.vcvttph2udq.256
    x86_avx512fp16_mask_vcvttph2udq_512,       // llvm.x86.avx512fp16.mask.vcvttph2udq.512
    x86_avx512fp16_mask_vcvttph2uqq_128,       // llvm.x86.avx512fp16.mask.vcvttph2uqq.128
    x86_avx512fp16_mask_vcvttph2uqq_256,       // llvm.x86.avx512fp16.mask.vcvttph2uqq.256
    x86_avx512fp16_mask_vcvttph2uqq_512,       // llvm.x86.avx512fp16.mask.vcvttph2uqq.512
    x86_avx512fp16_mask_vcvttph2uw_128,        // llvm.x86.avx512fp16.mask.vcvttph2uw.128
    x86_avx512fp16_mask_vcvttph2uw_256,        // llvm.x86.avx512fp16.mask.vcvttph2uw.256
    x86_avx512fp16_mask_vcvttph2uw_512,        // llvm.x86.avx512fp16.mask.vcvttph2uw.512
    x86_avx512fp16_mask_vcvttph2w_128,         // llvm.x86.avx512fp16.mask.vcvttph2w.128
    x86_avx512fp16_mask_vcvttph2w_256,         // llvm.x86.avx512fp16.mask.vcvttph2w.256
    x86_avx512fp16_mask_vcvttph2w_512,         // llvm.x86.avx512fp16.mask.vcvttph2w.512
    x86_avx512fp16_mask_vcvtudq2ph_128,        // llvm.x86.avx512fp16.mask.vcvtudq2ph.128
    x86_avx512fp16_mask_vcvtuqq2ph_128,        // llvm.x86.avx512fp16.mask.vcvtuqq2ph.128
    x86_avx512fp16_mask_vcvtuqq2ph_256,        // llvm.x86.avx512fp16.mask.vcvtuqq2ph.256
    x86_avx512fp16_mask_vfcmadd_cph_128,       // llvm.x86.avx512fp16.mask.vfcmadd.cph.128
    x86_avx512fp16_mask_vfcmadd_cph_256,       // llvm.x86.avx512fp16.mask.vfcmadd.cph.256
    x86_avx512fp16_mask_vfcmadd_cph_512,       // llvm.x86.avx512fp16.mask.vfcmadd.cph.512
    x86_avx512fp16_mask_vfcmadd_csh,           // llvm.x86.avx512fp16.mask.vfcmadd.csh
    x86_avx512fp16_mask_vfcmul_cph_128,        // llvm.x86.avx512fp16.mask.vfcmul.cph.128
    x86_avx512fp16_mask_vfcmul_cph_256,        // llvm.x86.avx512fp16.mask.vfcmul.cph.256
    x86_avx512fp16_mask_vfcmul_cph_512,        // llvm.x86.avx512fp16.mask.vfcmul.cph.512
    x86_avx512fp16_mask_vfcmul_csh,            // llvm.x86.avx512fp16.mask.vfcmul.csh
    x86_avx512fp16_mask_vfmadd_cph_128,        // llvm.x86.avx512fp16.mask.vfmadd.cph.128
    x86_avx512fp16_mask_vfmadd_cph_256,        // llvm.x86.avx512fp16.mask.vfmadd.cph.256
    x86_avx512fp16_mask_vfmadd_cph_512,        // llvm.x86.avx512fp16.mask.vfmadd.cph.512
    x86_avx512fp16_mask_vfmadd_csh,            // llvm.x86.avx512fp16.mask.vfmadd.csh
    x86_avx512fp16_mask_vfmul_cph_128,         // llvm.x86.avx512fp16.mask.vfmul.cph.128
    x86_avx512fp16_mask_vfmul_cph_256,         // llvm.x86.avx512fp16.mask.vfmul.cph.256
    x86_avx512fp16_mask_vfmul_cph_512,         // llvm.x86.avx512fp16.mask.vfmul.cph.512
    x86_avx512fp16_mask_vfmul_csh,             // llvm.x86.avx512fp16.mask.vfmul.csh
    x86_avx512fp16_maskz_vfcmadd_cph_128,      // llvm.x86.avx512fp16.maskz.vfcmadd.cph.128
    x86_avx512fp16_maskz_vfcmadd_cph_256,      // llvm.x86.avx512fp16.maskz.vfcmadd.cph.256
    x86_avx512fp16_maskz_vfcmadd_cph_512,      // llvm.x86.avx512fp16.maskz.vfcmadd.cph.512
    x86_avx512fp16_maskz_vfcmadd_csh,          // llvm.x86.avx512fp16.maskz.vfcmadd.csh
    x86_avx512fp16_maskz_vfmadd_cph_128,       // llvm.x86.avx512fp16.maskz.vfmadd.cph.128
    x86_avx512fp16_maskz_vfmadd_cph_256,       // llvm.x86.avx512fp16.maskz.vfmadd.cph.256
    x86_avx512fp16_maskz_vfmadd_cph_512,       // llvm.x86.avx512fp16.maskz.vfmadd.cph.512
    x86_avx512fp16_maskz_vfmadd_csh,           // llvm.x86.avx512fp16.maskz.vfmadd.csh
    x86_avx512fp16_max_ph_128,                 // llvm.x86.avx512fp16.max.ph.128
    x86_avx512fp16_max_ph_256,                 // llvm.x86.avx512fp16.max.ph.256
    x86_avx512fp16_max_ph_512,                 // llvm.x86.avx512fp16.max.ph.512
    x86_avx512fp16_min_ph_128,                 // llvm.x86.avx512fp16.min.ph.128
    x86_avx512fp16_min_ph_256,                 // llvm.x86.avx512fp16.min.ph.256
    x86_avx512fp16_min_ph_512,                 // llvm.x86.avx512fp16.min.ph.512
    x86_avx512fp16_mul_ph_512,                 // llvm.x86.avx512fp16.mul.ph.512
    x86_avx512fp16_sqrt_ph_512,                // llvm.x86.avx512fp16.sqrt.ph.512
    x86_avx512fp16_sub_ph_512,                 // llvm.x86.avx512fp16.sub.ph.512
    x86_avx512fp16_vcomi_sh,                   // llvm.x86.avx512fp16.vcomi.sh
    x86_avx512fp16_vcvtsh2si32,                // llvm.x86.avx512fp16.vcvtsh2si32
    x86_avx512fp16_vcvtsh2si64,                // llvm.x86.avx512fp16.vcvtsh2si64
    x86_avx512fp16_vcvtsh2usi32,               // llvm.x86.avx512fp16.vcvtsh2usi32
    x86_avx512fp16_vcvtsh2usi64,               // llvm.x86.avx512fp16.vcvtsh2usi64
    x86_avx512fp16_vcvtsi2sh,                  // llvm.x86.avx512fp16.vcvtsi2sh
    x86_avx512fp16_vcvtsi642sh,                // llvm.x86.avx512fp16.vcvtsi642sh
    x86_avx512fp16_vcvttsh2si32,               // llvm.x86.avx512fp16.vcvttsh2si32
    x86_avx512fp16_vcvttsh2si64,               // llvm.x86.avx512fp16.vcvttsh2si64
    x86_avx512fp16_vcvttsh2usi32,              // llvm.x86.avx512fp16.vcvttsh2usi32
    x86_avx512fp16_vcvttsh2usi64,              // llvm.x86.avx512fp16.vcvttsh2usi64
    x86_avx512fp16_vcvtusi2sh,                 // llvm.x86.avx512fp16.vcvtusi2sh
    x86_avx512fp16_vcvtusi642sh,               // llvm.x86.avx512fp16.vcvtusi642sh
    x86_avx512fp16_vfmadd_f16,                 // llvm.x86.avx512fp16.vfmadd.f16
    x86_avx512fp16_vfmadd_ph_512,              // llvm.x86.avx512fp16.vfmadd.ph.512
    x86_avx512fp16_vfmaddsub_ph_128,           // llvm.x86.avx512fp16.vfmaddsub.ph.128
    x86_avx512fp16_vfmaddsub_ph_256,           // llvm.x86.avx512fp16.vfmaddsub.ph.256
    x86_avx512fp16_vfmaddsub_ph_512,           // llvm.x86.avx512fp16.vfmaddsub.ph.512
    x86_axor32,                                // llvm.x86.axor32
    x86_axor64,                                // llvm.x86.axor64
    x86_bmi_bextr_32,                          // llvm.x86.bmi.bextr.32
    x86_bmi_bextr_64,                          // llvm.x86.bmi.bextr.64
    x86_bmi_bzhi_32,                           // llvm.x86.bmi.bzhi.32
    x86_bmi_bzhi_64,                           // llvm.x86.bmi.bzhi.64
    x86_bmi_pdep_32,                           // llvm.x86.bmi.pdep.32
    x86_bmi_pdep_64,                           // llvm.x86.bmi.pdep.64
    x86_bmi_pext_32,                           // llvm.x86.bmi.pext.32
    x86_bmi_pext_64,                           // llvm.x86.bmi.pext.64
    x86_cast_tile_to_vector,                   // llvm.x86.cast.tile.to.vector
    x86_cast_vector_to_tile,                   // llvm.x86.cast.vector.to.tile
    x86_cldemote,                              // llvm.x86.cldemote
    x86_clflushopt,                            // llvm.x86.clflushopt
    x86_clrssbsy,                              // llvm.x86.clrssbsy
    x86_clui,                                  // llvm.x86.clui
    x86_clwb,                                  // llvm.x86.clwb
    x86_clzero,                                // llvm.x86.clzero
    x86_cmpccxadd32,                           // llvm.x86.cmpccxadd32
    x86_cmpccxadd64,                           // llvm.x86.cmpccxadd64
    x86_directstore32,                         // llvm.x86.directstore32
    x86_directstore64,                         // llvm.x86.directstore64
    x86_encodekey128,                          // llvm.x86.encodekey128
    x86_encodekey256,                          // llvm.x86.encodekey256
    x86_enqcmd,                                // llvm.x86.enqcmd
    x86_enqcmds,                               // llvm.x86.enqcmds
    x86_flags_read_u32,                        // llvm.x86.flags.read.u32
    x86_flags_read_u64,                        // llvm.x86.flags.read.u64
    x86_flags_write_u32,                       // llvm.x86.flags.write.u32
    x86_flags_write_u64,                       // llvm.x86.flags.write.u64
    x86_fma_vfmaddsub_pd,                      // llvm.x86.fma.vfmaddsub.pd
    x86_fma_vfmaddsub_pd_256,                  // llvm.x86.fma.vfmaddsub.pd.256
    x86_fma_vfmaddsub_ps,                      // llvm.x86.fma.vfmaddsub.ps
    x86_fma_vfmaddsub_ps_256,                  // llvm.x86.fma.vfmaddsub.ps.256
    x86_fxrstor,                               // llvm.x86.fxrstor
    x86_fxrstor64,                             // llvm.x86.fxrstor64
    x86_fxsave,                                // llvm.x86.fxsave
    x86_fxsave64,                              // llvm.x86.fxsave64
    x86_incsspd,                               // llvm.x86.incsspd
    x86_incsspq,                               // llvm.x86.incsspq
    x86_int,                                   // llvm.x86.int
    x86_invpcid,                               // llvm.x86.invpcid
    x86_ldtilecfg,                             // llvm.x86.ldtilecfg
    x86_ldtilecfg_internal,                    // llvm.x86.ldtilecfg.internal
    x86_llwpcb,                                // llvm.x86.llwpcb
    x86_loadiwkey,                             // llvm.x86.loadiwkey
    x86_lwpins32,                              // llvm.x86.lwpins32
    x86_lwpins64,                              // llvm.x86.lwpins64
    x86_lwpval32,                              // llvm.x86.lwpval32
    x86_lwpval64,                              // llvm.x86.lwpval64
    x86_mmx_emms,                              // llvm.x86.mmx.emms
    x86_mmx_maskmovq,                          // llvm.x86.mmx.maskmovq
    x86_mmx_movnt_dq,                          // llvm.x86.mmx.movnt.dq
    x86_mmx_packssdw,                          // llvm.x86.mmx.packssdw
    x86_mmx_packsswb,                          // llvm.x86.mmx.packsswb
    x86_mmx_packuswb,                          // llvm.x86.mmx.packuswb
    x86_mmx_padd_b,                            // llvm.x86.mmx.padd.b
    x86_mmx_padd_d,                            // llvm.x86.mmx.padd.d
    x86_mmx_padd_q,                            // llvm.x86.mmx.padd.q
    x86_mmx_padd_w,                            // llvm.x86.mmx.padd.w
    x86_mmx_padds_b,                           // llvm.x86.mmx.padds.b
    x86_mmx_padds_w,                           // llvm.x86.mmx.padds.w
    x86_mmx_paddus_b,                          // llvm.x86.mmx.paddus.b
    x86_mmx_paddus_w,                          // llvm.x86.mmx.paddus.w
    x86_mmx_palignr_b,                         // llvm.x86.mmx.palignr.b
    x86_mmx_pand,                              // llvm.x86.mmx.pand
    x86_mmx_pandn,                             // llvm.x86.mmx.pandn
    x86_mmx_pavg_b,                            // llvm.x86.mmx.pavg.b
    x86_mmx_pavg_w,                            // llvm.x86.mmx.pavg.w
    x86_mmx_pcmpeq_b,                          // llvm.x86.mmx.pcmpeq.b
    x86_mmx_pcmpeq_d,                          // llvm.x86.mmx.pcmpeq.d
    x86_mmx_pcmpeq_w,                          // llvm.x86.mmx.pcmpeq.w
    x86_mmx_pcmpgt_b,                          // llvm.x86.mmx.pcmpgt.b
    x86_mmx_pcmpgt_d,                          // llvm.x86.mmx.pcmpgt.d
    x86_mmx_pcmpgt_w,                          // llvm.x86.mmx.pcmpgt.w
    x86_mmx_pextr_w,                           // llvm.x86.mmx.pextr.w
    x86_mmx_pinsr_w,                           // llvm.x86.mmx.pinsr.w
    x86_mmx_pmadd_wd,                          // llvm.x86.mmx.pmadd.wd
    x86_mmx_pmaxs_w,                           // llvm.x86.mmx.pmaxs.w
    x86_mmx_pmaxu_b,                           // llvm.x86.mmx.pmaxu.b
    x86_mmx_pmins_w,                           // llvm.x86.mmx.pmins.w
    x86_mmx_pminu_b,                           // llvm.x86.mmx.pminu.b
    x86_mmx_pmovmskb,                          // llvm.x86.mmx.pmovmskb
    x86_mmx_pmulh_w,                           // llvm.x86.mmx.pmulh.w
    x86_mmx_pmulhu_w,                          // llvm.x86.mmx.pmulhu.w
    x86_mmx_pmull_w,                           // llvm.x86.mmx.pmull.w
    x86_mmx_pmulu_dq,                          // llvm.x86.mmx.pmulu.dq
    x86_mmx_por,                               // llvm.x86.mmx.por
    x86_mmx_psad_bw,                           // llvm.x86.mmx.psad.bw
    x86_mmx_psll_d,                            // llvm.x86.mmx.psll.d
    x86_mmx_psll_q,                            // llvm.x86.mmx.psll.q
    x86_mmx_psll_w,                            // llvm.x86.mmx.psll.w
    x86_mmx_pslli_d,                           // llvm.x86.mmx.pslli.d
    x86_mmx_pslli_q,                           // llvm.x86.mmx.pslli.q
    x86_mmx_pslli_w,                           // llvm.x86.mmx.pslli.w
    x86_mmx_psra_d,                            // llvm.x86.mmx.psra.d
    x86_mmx_psra_w,                            // llvm.x86.mmx.psra.w
    x86_mmx_psrai_d,                           // llvm.x86.mmx.psrai.d
    x86_mmx_psrai_w,                           // llvm.x86.mmx.psrai.w
    x86_mmx_psrl_d,                            // llvm.x86.mmx.psrl.d
    x86_mmx_psrl_q,                            // llvm.x86.mmx.psrl.q
    x86_mmx_psrl_w,                            // llvm.x86.mmx.psrl.w
    x86_mmx_psrli_d,                           // llvm.x86.mmx.psrli.d
    x86_mmx_psrli_q,                           // llvm.x86.mmx.psrli.q
    x86_mmx_psrli_w,                           // llvm.x86.mmx.psrli.w
    x86_mmx_psub_b,                            // llvm.x86.mmx.psub.b
    x86_mmx_psub_d,                            // llvm.x86.mmx.psub.d
    x86_mmx_psub_q,                            // llvm.x86.mmx.psub.q
    x86_mmx_psub_w,                            // llvm.x86.mmx.psub.w
    x86_mmx_psubs_b,                           // llvm.x86.mmx.psubs.b
    x86_mmx_psubs_w,                           // llvm.x86.mmx.psubs.w
    x86_mmx_psubus_b,                          // llvm.x86.mmx.psubus.b
    x86_mmx_psubus_w,                          // llvm.x86.mmx.psubus.w
    x86_mmx_punpckhbw,                         // llvm.x86.mmx.punpckhbw
    x86_mmx_punpckhdq,                         // llvm.x86.mmx.punpckhdq
    x86_mmx_punpckhwd,                         // llvm.x86.mmx.punpckhwd
    x86_mmx_punpcklbw,                         // llvm.x86.mmx.punpcklbw
    x86_mmx_punpckldq,                         // llvm.x86.mmx.punpckldq
    x86_mmx_punpcklwd,                         // llvm.x86.mmx.punpcklwd
    x86_mmx_pxor,                              // llvm.x86.mmx.pxor
    x86_monitorx,                              // llvm.x86.monitorx
    x86_movdir64b,                             // llvm.x86.movdir64b
    x86_movrsdi,                               // llvm.x86.movrsdi
    x86_movrshi,                               // llvm.x86.movrshi
    x86_movrsqi,                               // llvm.x86.movrsqi
    x86_movrssi,                               // llvm.x86.movrssi
    x86_mwaitx,                                // llvm.x86.mwaitx
    x86_pclmulqdq,                             // llvm.x86.pclmulqdq
    x86_pclmulqdq_256,                         // llvm.x86.pclmulqdq.256
    x86_pclmulqdq_512,                         // llvm.x86.pclmulqdq.512
    x86_prefetchrs,                            // llvm.x86.prefetchrs
    x86_ptwrite32,                             // llvm.x86.ptwrite32
    x86_ptwrite64,                             // llvm.x86.ptwrite64
    x86_rdfsbase_32,                           // llvm.x86.rdfsbase.32
    x86_rdfsbase_64,                           // llvm.x86.rdfsbase.64
    x86_rdgsbase_32,                           // llvm.x86.rdgsbase.32
    x86_rdgsbase_64,                           // llvm.x86.rdgsbase.64
    x86_rdpid,                                 // llvm.x86.rdpid
    x86_rdpkru,                                // llvm.x86.rdpkru
    x86_rdpmc,                                 // llvm.x86.rdpmc
    x86_rdpru,                                 // llvm.x86.rdpru
    x86_rdrand_16,                             // llvm.x86.rdrand.16
    x86_rdrand_32,                             // llvm.x86.rdrand.32
    x86_rdrand_64,                             // llvm.x86.rdrand.64
    x86_rdseed_16,                             // llvm.x86.rdseed.16
    x86_rdseed_32,                             // llvm.x86.rdseed.32
    x86_rdseed_64,                             // llvm.x86.rdseed.64
    x86_rdsspd,                                // llvm.x86.rdsspd
    x86_rdsspq,                                // llvm.x86.rdsspq
    x86_rdtsc,                                 // llvm.x86.rdtsc
    x86_rdtscp,                                // llvm.x86.rdtscp
    x86_rstorssp,                              // llvm.x86.rstorssp
    x86_saveprevssp,                           // llvm.x86.saveprevssp
    x86_seh_ehguard,                           // llvm.x86.seh.ehguard
    x86_seh_ehregnode,                         // llvm.x86.seh.ehregnode
    x86_seh_lsda,                              // llvm.x86.seh.lsda
    x86_senduipi,                              // llvm.x86.senduipi
    x86_serialize,                             // llvm.x86.serialize
    x86_setssbsy,                              // llvm.x86.setssbsy
    x86_sha1msg1,                              // llvm.x86.sha1msg1
    x86_sha1msg2,                              // llvm.x86.sha1msg2
    x86_sha1nexte,                             // llvm.x86.sha1nexte
    x86_sha1rnds4,                             // llvm.x86.sha1rnds4
    x86_sha256msg1,                            // llvm.x86.sha256msg1
    x86_sha256msg2,                            // llvm.x86.sha256msg2
    x86_sha256rnds2,                           // llvm.x86.sha256rnds2
    x86_slwpcb,                                // llvm.x86.slwpcb
    x86_sse_cmp_ps,                            // llvm.x86.sse.cmp.ps
    x86_sse_cmp_ss,                            // llvm.x86.sse.cmp.ss
    x86_sse_comieq_ss,                         // llvm.x86.sse.comieq.ss
    x86_sse_comige_ss,                         // llvm.x86.sse.comige.ss
    x86_sse_comigt_ss,                         // llvm.x86.sse.comigt.ss
    x86_sse_comile_ss,                         // llvm.x86.sse.comile.ss
    x86_sse_comilt_ss,                         // llvm.x86.sse.comilt.ss
    x86_sse_comineq_ss,                        // llvm.x86.sse.comineq.ss
    x86_sse_cvtpd2pi,                          // llvm.x86.sse.cvtpd2pi
    x86_sse_cvtpi2pd,                          // llvm.x86.sse.cvtpi2pd
    x86_sse_cvtpi2ps,                          // llvm.x86.sse.cvtpi2ps
    x86_sse_cvtps2pi,                          // llvm.x86.sse.cvtps2pi
    x86_sse_cvtss2si,                          // llvm.x86.sse.cvtss2si
    x86_sse_cvtss2si64,                        // llvm.x86.sse.cvtss2si64
    x86_sse_cvttpd2pi,                         // llvm.x86.sse.cvttpd2pi
    x86_sse_cvttps2pi,                         // llvm.x86.sse.cvttps2pi
    x86_sse_cvttss2si,                         // llvm.x86.sse.cvttss2si
    x86_sse_cvttss2si64,                       // llvm.x86.sse.cvttss2si64
    x86_sse_ldmxcsr,                           // llvm.x86.sse.ldmxcsr
    x86_sse_max_ps,                            // llvm.x86.sse.max.ps
    x86_sse_max_ss,                            // llvm.x86.sse.max.ss
    x86_sse_min_ps,                            // llvm.x86.sse.min.ps
    x86_sse_min_ss,                            // llvm.x86.sse.min.ss
    x86_sse_movmsk_ps,                         // llvm.x86.sse.movmsk.ps
    x86_sse_pshuf_w,                           // llvm.x86.sse.pshuf.w
    x86_sse_rcp_ps,                            // llvm.x86.sse.rcp.ps
    x86_sse_rcp_ss,                            // llvm.x86.sse.rcp.ss
    x86_sse_rsqrt_ps,                          // llvm.x86.sse.rsqrt.ps
    x86_sse_rsqrt_ss,                          // llvm.x86.sse.rsqrt.ss
    x86_sse_sfence,                            // llvm.x86.sse.sfence
    x86_sse_stmxcsr,                           // llvm.x86.sse.stmxcsr
    x86_sse_ucomieq_ss,                        // llvm.x86.sse.ucomieq.ss
    x86_sse_ucomige_ss,                        // llvm.x86.sse.ucomige.ss
    x86_sse_ucomigt_ss,                        // llvm.x86.sse.ucomigt.ss
    x86_sse_ucomile_ss,                        // llvm.x86.sse.ucomile.ss
    x86_sse_ucomilt_ss,                        // llvm.x86.sse.ucomilt.ss
    x86_sse_ucomineq_ss,                       // llvm.x86.sse.ucomineq.ss
    x86_sse2_clflush,                          // llvm.x86.sse2.clflush
    x86_sse2_cmp_pd,                           // llvm.x86.sse2.cmp.pd
    x86_sse2_cmp_sd,                           // llvm.x86.sse2.cmp.sd
    x86_sse2_comieq_sd,                        // llvm.x86.sse2.comieq.sd
    x86_sse2_comige_sd,                        // llvm.x86.sse2.comige.sd
    x86_sse2_comigt_sd,                        // llvm.x86.sse2.comigt.sd
    x86_sse2_comile_sd,                        // llvm.x86.sse2.comile.sd
    x86_sse2_comilt_sd,                        // llvm.x86.sse2.comilt.sd
    x86_sse2_comineq_sd,                       // llvm.x86.sse2.comineq.sd
    x86_sse2_cvtpd2dq,                         // llvm.x86.sse2.cvtpd2dq
    x86_sse2_cvtpd2ps,                         // llvm.x86.sse2.cvtpd2ps
    x86_sse2_cvtps2dq,                         // llvm.x86.sse2.cvtps2dq
    x86_sse2_cvtsd2si,                         // llvm.x86.sse2.cvtsd2si
    x86_sse2_cvtsd2si64,                       // llvm.x86.sse2.cvtsd2si64
    x86_sse2_cvtsd2ss,                         // llvm.x86.sse2.cvtsd2ss
    x86_sse2_cvttpd2dq,                        // llvm.x86.sse2.cvttpd2dq
    x86_sse2_cvttps2dq,                        // llvm.x86.sse2.cvttps2dq
    x86_sse2_cvttsd2si,                        // llvm.x86.sse2.cvttsd2si
    x86_sse2_cvttsd2si64,                      // llvm.x86.sse2.cvttsd2si64
    x86_sse2_lfence,                           // llvm.x86.sse2.lfence
    x86_sse2_maskmov_dqu,                      // llvm.x86.sse2.maskmov.dqu
    x86_sse2_max_pd,                           // llvm.x86.sse2.max.pd
    x86_sse2_max_sd,                           // llvm.x86.sse2.max.sd
    x86_sse2_mfence,                           // llvm.x86.sse2.mfence
    x86_sse2_min_pd,                           // llvm.x86.sse2.min.pd
    x86_sse2_min_sd,                           // llvm.x86.sse2.min.sd
    x86_sse2_movmsk_pd,                        // llvm.x86.sse2.movmsk.pd
    x86_sse2_packssdw_128,                     // llvm.x86.sse2.packssdw.128
    x86_sse2_packsswb_128,                     // llvm.x86.sse2.packsswb.128
    x86_sse2_packuswb_128,                     // llvm.x86.sse2.packuswb.128
    x86_sse2_pause,                            // llvm.x86.sse2.pause
    x86_sse2_pavg_b,                           // llvm.x86.sse2.pavg.b
    x86_sse2_pavg_w,                           // llvm.x86.sse2.pavg.w
    x86_sse2_pmadd_wd,                         // llvm.x86.sse2.pmadd.wd
    x86_sse2_pmovmskb_128,                     // llvm.x86.sse2.pmovmskb.128
    x86_sse2_pmulh_w,                          // llvm.x86.sse2.pmulh.w
    x86_sse2_pmulhu_w,                         // llvm.x86.sse2.pmulhu.w
    x86_sse2_psad_bw,                          // llvm.x86.sse2.psad.bw
    x86_sse2_psll_d,                           // llvm.x86.sse2.psll.d
    x86_sse2_psll_q,                           // llvm.x86.sse2.psll.q
    x86_sse2_psll_w,                           // llvm.x86.sse2.psll.w
    x86_sse2_pslli_d,                          // llvm.x86.sse2.pslli.d
    x86_sse2_pslli_q,                          // llvm.x86.sse2.pslli.q
    x86_sse2_pslli_w,                          // llvm.x86.sse2.pslli.w
    x86_sse2_psra_d,                           // llvm.x86.sse2.psra.d
    x86_sse2_psra_w,                           // llvm.x86.sse2.psra.w
    x86_sse2_psrai_d,                          // llvm.x86.sse2.psrai.d
    x86_sse2_psrai_w,                          // llvm.x86.sse2.psrai.w
    x86_sse2_psrl_d,                           // llvm.x86.sse2.psrl.d
    x86_sse2_psrl_q,                           // llvm.x86.sse2.psrl.q
    x86_sse2_psrl_w,                           // llvm.x86.sse2.psrl.w
    x86_sse2_psrli_d,                          // llvm.x86.sse2.psrli.d
    x86_sse2_psrli_q,                          // llvm.x86.sse2.psrli.q
    x86_sse2_psrli_w,                          // llvm.x86.sse2.psrli.w
    x86_sse2_ucomieq_sd,                       // llvm.x86.sse2.ucomieq.sd
    x86_sse2_ucomige_sd,                       // llvm.x86.sse2.ucomige.sd
    x86_sse2_ucomigt_sd,                       // llvm.x86.sse2.ucomigt.sd
    x86_sse2_ucomile_sd,                       // llvm.x86.sse2.ucomile.sd
    x86_sse2_ucomilt_sd,                       // llvm.x86.sse2.ucomilt.sd
    x86_sse2_ucomineq_sd,                      // llvm.x86.sse2.ucomineq.sd
    x86_sse3_addsub_pd,                        // llvm.x86.sse3.addsub.pd
    x86_sse3_addsub_ps,                        // llvm.x86.sse3.addsub.ps
    x86_sse3_hadd_pd,                          // llvm.x86.sse3.hadd.pd
    x86_sse3_hadd_ps,                          // llvm.x86.sse3.hadd.ps
    x86_sse3_hsub_pd,                          // llvm.x86.sse3.hsub.pd
    x86_sse3_hsub_ps,                          // llvm.x86.sse3.hsub.ps
    x86_sse3_ldu_dq,                           // llvm.x86.sse3.ldu.dq
    x86_sse3_monitor,                          // llvm.x86.sse3.monitor
    x86_sse3_mwait,                            // llvm.x86.sse3.mwait
    x86_sse41_blendvpd,                        // llvm.x86.sse41.blendvpd
    x86_sse41_blendvps,                        // llvm.x86.sse41.blendvps
    x86_sse41_dppd,                            // llvm.x86.sse41.dppd
    x86_sse41_dpps,                            // llvm.x86.sse41.dpps
    x86_sse41_insertps,                        // llvm.x86.sse41.insertps
    x86_sse41_mpsadbw,                         // llvm.x86.sse41.mpsadbw
    x86_sse41_packusdw,                        // llvm.x86.sse41.packusdw
    x86_sse41_pblendvb,                        // llvm.x86.sse41.pblendvb
    x86_sse41_phminposuw,                      // llvm.x86.sse41.phminposuw
    x86_sse41_ptestc,                          // llvm.x86.sse41.ptestc
    x86_sse41_ptestnzc,                        // llvm.x86.sse41.ptestnzc
    x86_sse41_ptestz,                          // llvm.x86.sse41.ptestz
    x86_sse41_round_pd,                        // llvm.x86.sse41.round.pd
    x86_sse41_round_ps,                        // llvm.x86.sse41.round.ps
    x86_sse41_round_sd,                        // llvm.x86.sse41.round.sd
    x86_sse41_round_ss,                        // llvm.x86.sse41.round.ss
    x86_sse42_crc32_32_16,                     // llvm.x86.sse42.crc32.32.16
    x86_sse42_crc32_32_32,                     // llvm.x86.sse42.crc32.32.32
    x86_sse42_crc32_32_8,                      // llvm.x86.sse42.crc32.32.8
    x86_sse42_crc32_64_64,                     // llvm.x86.sse42.crc32.64.64
    x86_sse42_pcmpestri128,                    // llvm.x86.sse42.pcmpestri128
    x86_sse42_pcmpestria128,                   // llvm.x86.sse42.pcmpestria128
    x86_sse42_pcmpestric128,                   // llvm.x86.sse42.pcmpestric128
    x86_sse42_pcmpestrio128,                   // llvm.x86.sse42.pcmpestrio128
    x86_sse42_pcmpestris128,                   // llvm.x86.sse42.pcmpestris128
    x86_sse42_pcmpestriz128,                   // llvm.x86.sse42.pcmpestriz128
    x86_sse42_pcmpestrm128,                    // llvm.x86.sse42.pcmpestrm128
    x86_sse42_pcmpistri128,                    // llvm.x86.sse42.pcmpistri128
    x86_sse42_pcmpistria128,                   // llvm.x86.sse42.pcmpistria128
    x86_sse42_pcmpistric128,                   // llvm.x86.sse42.pcmpistric128
    x86_sse42_pcmpistrio128,                   // llvm.x86.sse42.pcmpistrio128
    x86_sse42_pcmpistris128,                   // llvm.x86.sse42.pcmpistris128
    x86_sse42_pcmpistriz128,                   // llvm.x86.sse42.pcmpistriz128
    x86_sse42_pcmpistrm128,                    // llvm.x86.sse42.pcmpistrm128
    x86_sse4a_extrq,                           // llvm.x86.sse4a.extrq
    x86_sse4a_extrqi,                          // llvm.x86.sse4a.extrqi
    x86_sse4a_insertq,                         // llvm.x86.sse4a.insertq
    x86_sse4a_insertqi,                        // llvm.x86.sse4a.insertqi
    x86_ssse3_pabs_b,                          // llvm.x86.ssse3.pabs.b
    x86_ssse3_pabs_d,                          // llvm.x86.ssse3.pabs.d
    x86_ssse3_pabs_w,                          // llvm.x86.ssse3.pabs.w
    x86_ssse3_phadd_d,                         // llvm.x86.ssse3.phadd.d
    x86_ssse3_phadd_d_128,                     // llvm.x86.ssse3.phadd.d.128
    x86_ssse3_phadd_sw,                        // llvm.x86.ssse3.phadd.sw
    x86_ssse3_phadd_sw_128,                    // llvm.x86.ssse3.phadd.sw.128
    x86_ssse3_phadd_w,                         // llvm.x86.ssse3.phadd.w
    x86_ssse3_phadd_w_128,                     // llvm.x86.ssse3.phadd.w.128
    x86_ssse3_phsub_d,                         // llvm.x86.ssse3.phsub.d
    x86_ssse3_phsub_d_128,                     // llvm.x86.ssse3.phsub.d.128
    x86_ssse3_phsub_sw,                        // llvm.x86.ssse3.phsub.sw
    x86_ssse3_phsub_sw_128,                    // llvm.x86.ssse3.phsub.sw.128
    x86_ssse3_phsub_w,                         // llvm.x86.ssse3.phsub.w
    x86_ssse3_phsub_w_128,                     // llvm.x86.ssse3.phsub.w.128
    x86_ssse3_pmadd_ub_sw,                     // llvm.x86.ssse3.pmadd.ub.sw
    x86_ssse3_pmadd_ub_sw_128,                 // llvm.x86.ssse3.pmadd.ub.sw.128
    x86_ssse3_pmul_hr_sw,                      // llvm.x86.ssse3.pmul.hr.sw
    x86_ssse3_pmul_hr_sw_128,                  // llvm.x86.ssse3.pmul.hr.sw.128
    x86_ssse3_pshuf_b,                         // llvm.x86.ssse3.pshuf.b
    x86_ssse3_pshuf_b_128,                     // llvm.x86.ssse3.pshuf.b.128
    x86_ssse3_psign_b,                         // llvm.x86.ssse3.psign.b
    x86_ssse3_psign_b_128,                     // llvm.x86.ssse3.psign.b.128
    x86_ssse3_psign_d,                         // llvm.x86.ssse3.psign.d
    x86_ssse3_psign_d_128,                     // llvm.x86.ssse3.psign.d.128
    x86_ssse3_psign_w,                         // llvm.x86.ssse3.psign.w
    x86_ssse3_psign_w_128,                     // llvm.x86.ssse3.psign.w.128
    x86_sttilecfg,                             // llvm.x86.sttilecfg
    x86_stui,                                  // llvm.x86.stui
    x86_subborrow_32,                          // llvm.x86.subborrow.32
    x86_subborrow_64,                          // llvm.x86.subborrow.64
    x86_t2rpntlvwz0,                           // llvm.x86.t2rpntlvwz0
    x86_t2rpntlvwz0_internal,                  // llvm.x86.t2rpntlvwz0.internal
    x86_t2rpntlvwz0rs,                         // llvm.x86.t2rpntlvwz0rs
    x86_t2rpntlvwz0rs_internal,                // llvm.x86.t2rpntlvwz0rs.internal
    x86_t2rpntlvwz0rst1,                       // llvm.x86.t2rpntlvwz0rst1
    x86_t2rpntlvwz0rst1_internal,              // llvm.x86.t2rpntlvwz0rst1.internal
    x86_t2rpntlvwz0t1,                         // llvm.x86.t2rpntlvwz0t1
    x86_t2rpntlvwz0t1_internal,                // llvm.x86.t2rpntlvwz0t1.internal
    x86_t2rpntlvwz1,                           // llvm.x86.t2rpntlvwz1
    x86_t2rpntlvwz1_internal,                  // llvm.x86.t2rpntlvwz1.internal
    x86_t2rpntlvwz1rs,                         // llvm.x86.t2rpntlvwz1rs
    x86_t2rpntlvwz1rs_internal,                // llvm.x86.t2rpntlvwz1rs.internal
    x86_t2rpntlvwz1rst1,                       // llvm.x86.t2rpntlvwz1rst1
    x86_t2rpntlvwz1rst1_internal,              // llvm.x86.t2rpntlvwz1rst1.internal
    x86_t2rpntlvwz1t1,                         // llvm.x86.t2rpntlvwz1t1
    x86_t2rpntlvwz1t1_internal,                // llvm.x86.t2rpntlvwz1t1.internal
    x86_tbm_bextri_u32,                        // llvm.x86.tbm.bextri.u32
    x86_tbm_bextri_u64,                        // llvm.x86.tbm.bextri.u64
    x86_tcmmimfp16ps,                          // llvm.x86.tcmmimfp16ps
    x86_tcmmimfp16ps_internal,                 // llvm.x86.tcmmimfp16ps.internal
    x86_tcmmrlfp16ps,                          // llvm.x86.tcmmrlfp16ps
    x86_tcmmrlfp16ps_internal,                 // llvm.x86.tcmmrlfp16ps.internal
    x86_tconjtcmmimfp16ps,                     // llvm.x86.tconjtcmmimfp16ps
    x86_tconjtcmmimfp16ps_internal,            // llvm.x86.tconjtcmmimfp16ps.internal
    x86_tconjtfp16,                            // llvm.x86.tconjtfp16
    x86_tconjtfp16_internal,                   // llvm.x86.tconjtfp16.internal
    x86_tcvtrowd2ps,                           // llvm.x86.tcvtrowd2ps
    x86_tcvtrowd2ps_internal,                  // llvm.x86.tcvtrowd2ps.internal
    x86_tcvtrowps2bf16h,                       // llvm.x86.tcvtrowps2bf16h
    x86_tcvtrowps2bf16h_internal,              // llvm.x86.tcvtrowps2bf16h.internal
    x86_tcvtrowps2bf16l,                       // llvm.x86.tcvtrowps2bf16l
    x86_tcvtrowps2bf16l_internal,              // llvm.x86.tcvtrowps2bf16l.internal
    x86_tcvtrowps2phh,                         // llvm.x86.tcvtrowps2phh
    x86_tcvtrowps2phh_internal,                // llvm.x86.tcvtrowps2phh.internal
    x86_tcvtrowps2phl,                         // llvm.x86.tcvtrowps2phl
    x86_tcvtrowps2phl_internal,                // llvm.x86.tcvtrowps2phl.internal
    x86_tdpbf16ps,                             // llvm.x86.tdpbf16ps
    x86_tdpbf16ps_internal,                    // llvm.x86.tdpbf16ps.internal
    x86_tdpbf8ps,                              // llvm.x86.tdpbf8ps
    x86_tdpbf8ps_internal,                     // llvm.x86.tdpbf8ps.internal
    x86_tdpbhf8ps,                             // llvm.x86.tdpbhf8ps
    x86_tdpbhf8ps_internal,                    // llvm.x86.tdpbhf8ps.internal
    x86_tdpbssd,                               // llvm.x86.tdpbssd
    x86_tdpbssd_internal,                      // llvm.x86.tdpbssd.internal
    x86_tdpbsud,                               // llvm.x86.tdpbsud
    x86_tdpbsud_internal,                      // llvm.x86.tdpbsud.internal
    x86_tdpbusd,                               // llvm.x86.tdpbusd
    x86_tdpbusd_internal,                      // llvm.x86.tdpbusd.internal
    x86_tdpbuud,                               // llvm.x86.tdpbuud
    x86_tdpbuud_internal,                      // llvm.x86.tdpbuud.internal
    x86_tdpfp16ps,                             // llvm.x86.tdpfp16ps
    x86_tdpfp16ps_internal,                    // llvm.x86.tdpfp16ps.internal
    x86_tdphbf8ps,                             // llvm.x86.tdphbf8ps
    x86_tdphbf8ps_internal,                    // llvm.x86.tdphbf8ps.internal
    x86_tdphf8ps,                              // llvm.x86.tdphf8ps
    x86_tdphf8ps_internal,                     // llvm.x86.tdphf8ps.internal
    x86_testui,                                // llvm.x86.testui
    x86_tileloadd64,                           // llvm.x86.tileloadd64
    x86_tileloadd64_internal,                  // llvm.x86.tileloadd64.internal
    x86_tileloaddrs64,                         // llvm.x86.tileloaddrs64
    x86_tileloaddrs64_internal,                // llvm.x86.tileloaddrs64.internal
    x86_tileloaddrst164,                       // llvm.x86.tileloaddrst164
    x86_tileloaddrst164_internal,              // llvm.x86.tileloaddrst164.internal
    x86_tileloaddt164,                         // llvm.x86.tileloaddt164
    x86_tileloaddt164_internal,                // llvm.x86.tileloaddt164.internal
    x86_tilemovrow,                            // llvm.x86.tilemovrow
    x86_tilemovrow_internal,                   // llvm.x86.tilemovrow.internal
    x86_tilerelease,                           // llvm.x86.tilerelease
    x86_tilestored64,                          // llvm.x86.tilestored64
    x86_tilestored64_internal,                 // llvm.x86.tilestored64.internal
    x86_tilezero,                              // llvm.x86.tilezero
    x86_tilezero_internal,                     // llvm.x86.tilezero.internal
    x86_tmmultf32ps,                           // llvm.x86.tmmultf32ps
    x86_tmmultf32ps_internal,                  // llvm.x86.tmmultf32ps.internal
    x86_tpause,                                // llvm.x86.tpause
    x86_ttcmmimfp16ps,                         // llvm.x86.ttcmmimfp16ps
    x86_ttcmmimfp16ps_internal,                // llvm.x86.ttcmmimfp16ps.internal
    x86_ttcmmrlfp16ps,                         // llvm.x86.ttcmmrlfp16ps
    x86_ttcmmrlfp16ps_internal,                // llvm.x86.ttcmmrlfp16ps.internal
    x86_ttdpbf16ps,                            // llvm.x86.ttdpbf16ps
    x86_ttdpbf16ps_internal,                   // llvm.x86.ttdpbf16ps.internal
    x86_ttdpfp16ps,                            // llvm.x86.ttdpfp16ps
    x86_ttdpfp16ps_internal,                   // llvm.x86.ttdpfp16ps.internal
    x86_ttmmultf32ps,                          // llvm.x86.ttmmultf32ps
    x86_ttmmultf32ps_internal,                 // llvm.x86.ttmmultf32ps.internal
    x86_ttransposed,                           // llvm.x86.ttransposed
    x86_ttransposed_internal,                  // llvm.x86.ttransposed.internal
    x86_umonitor,                              // llvm.x86.umonitor
    x86_umwait,                                // llvm.x86.umwait
    x86_urdmsr,                                // llvm.x86.urdmsr
    x86_uwrmsr,                                // llvm.x86.uwrmsr
    x86_vbcstnebf162ps128,                     // llvm.x86.vbcstnebf162ps128
    x86_vbcstnebf162ps256,                     // llvm.x86.vbcstnebf162ps256
    x86_vbcstnesh2ps128,                       // llvm.x86.vbcstnesh2ps128
    x86_vbcstnesh2ps256,                       // llvm.x86.vbcstnesh2ps256
    x86_vcvtneebf162ps128,                     // llvm.x86.vcvtneebf162ps128
    x86_vcvtneebf162ps256,                     // llvm.x86.vcvtneebf162ps256
    x86_vcvtneeph2ps128,                       // llvm.x86.vcvtneeph2ps128
    x86_vcvtneeph2ps256,                       // llvm.x86.vcvtneeph2ps256
    x86_vcvtneobf162ps128,                     // llvm.x86.vcvtneobf162ps128
    x86_vcvtneobf162ps256,                     // llvm.x86.vcvtneobf162ps256
    x86_vcvtneoph2ps128,                       // llvm.x86.vcvtneoph2ps128
    x86_vcvtneoph2ps256,                       // llvm.x86.vcvtneoph2ps256
    x86_vcvtneps2bf16128,                      // llvm.x86.vcvtneps2bf16128
    x86_vcvtneps2bf16256,                      // llvm.x86.vcvtneps2bf16256
    x86_vcvtps2ph_128,                         // llvm.x86.vcvtps2ph.128
    x86_vcvtps2ph_256,                         // llvm.x86.vcvtps2ph.256
    x86_vgf2p8affineinvqb_128,                 // llvm.x86.vgf2p8affineinvqb.128
    x86_vgf2p8affineinvqb_256,                 // llvm.x86.vgf2p8affineinvqb.256
    x86_vgf2p8affineinvqb_512,                 // llvm.x86.vgf2p8affineinvqb.512
    x86_vgf2p8affineqb_128,                    // llvm.x86.vgf2p8affineqb.128
    x86_vgf2p8affineqb_256,                    // llvm.x86.vgf2p8affineqb.256
    x86_vgf2p8affineqb_512,                    // llvm.x86.vgf2p8affineqb.512
    x86_vgf2p8mulb_128,                        // llvm.x86.vgf2p8mulb.128
    x86_vgf2p8mulb_256,                        // llvm.x86.vgf2p8mulb.256
    x86_vgf2p8mulb_512,                        // llvm.x86.vgf2p8mulb.512
    x86_vsha512msg1,                           // llvm.x86.vsha512msg1
    x86_vsha512msg2,                           // llvm.x86.vsha512msg2
    x86_vsha512rnds2,                          // llvm.x86.vsha512rnds2
    x86_vsm3msg1,                              // llvm.x86.vsm3msg1
    x86_vsm3msg2,                              // llvm.x86.vsm3msg2
    x86_vsm3rnds2,                             // llvm.x86.vsm3rnds2
    x86_vsm4key4128,                           // llvm.x86.vsm4key4128
    x86_vsm4key4256,                           // llvm.x86.vsm4key4256
    x86_vsm4key4512,                           // llvm.x86.vsm4key4512
    x86_vsm4rnds4128,                          // llvm.x86.vsm4rnds4128
    x86_vsm4rnds4256,                          // llvm.x86.vsm4rnds4256
    x86_vsm4rnds4512,                          // llvm.x86.vsm4rnds4512
    x86_wbinvd,                                // llvm.x86.wbinvd
    x86_wbnoinvd,                              // llvm.x86.wbnoinvd
    x86_wrfsbase_32,                           // llvm.x86.wrfsbase.32
    x86_wrfsbase_64,                           // llvm.x86.wrfsbase.64
    x86_wrgsbase_32,                           // llvm.x86.wrgsbase.32
    x86_wrgsbase_64,                           // llvm.x86.wrgsbase.64
    x86_wrpkru,                                // llvm.x86.wrpkru
    x86_wrssd,                                 // llvm.x86.wrssd
    x86_wrssq,                                 // llvm.x86.wrssq
    x86_wrussd,                                // llvm.x86.wrussd
    x86_wrussq,                                // llvm.x86.wrussq
    x86_xabort,                                // llvm.x86.xabort
    x86_xbegin,                                // llvm.x86.xbegin
    x86_xend,                                  // llvm.x86.xend
    x86_xgetbv,                                // llvm.x86.xgetbv
    x86_xop_vfrcz_pd,                          // llvm.x86.xop.vfrcz.pd
    x86_xop_vfrcz_pd_256,                      // llvm.x86.xop.vfrcz.pd.256
    x86_xop_vfrcz_ps,                          // llvm.x86.xop.vfrcz.ps
    x86_xop_vfrcz_ps_256,                      // llvm.x86.xop.vfrcz.ps.256
    x86_xop_vfrcz_sd,                          // llvm.x86.xop.vfrcz.sd
    x86_xop_vfrcz_ss,                          // llvm.x86.xop.vfrcz.ss
    x86_xop_vpermil2pd,                        // llvm.x86.xop.vpermil2pd
    x86_xop_vpermil2pd_256,                    // llvm.x86.xop.vpermil2pd.256
    x86_xop_vpermil2ps,                        // llvm.x86.xop.vpermil2ps
    x86_xop_vpermil2ps_256,                    // llvm.x86.xop.vpermil2ps.256
    x86_xop_vphaddbd,                          // llvm.x86.xop.vphaddbd
    x86_xop_vphaddbq,                          // llvm.x86.xop.vphaddbq
    x86_xop_vphaddbw,                          // llvm.x86.xop.vphaddbw
    x86_xop_vphadddq,                          // llvm.x86.xop.vphadddq
    x86_xop_vphaddubd,                         // llvm.x86.xop.vphaddubd
    x86_xop_vphaddubq,                         // llvm.x86.xop.vphaddubq
    x86_xop_vphaddubw,                         // llvm.x86.xop.vphaddubw
    x86_xop_vphaddudq,                         // llvm.x86.xop.vphaddudq
    x86_xop_vphadduwd,                         // llvm.x86.xop.vphadduwd
    x86_xop_vphadduwq,                         // llvm.x86.xop.vphadduwq
    x86_xop_vphaddwd,                          // llvm.x86.xop.vphaddwd
    x86_xop_vphaddwq,                          // llvm.x86.xop.vphaddwq
    x86_xop_vphsubbw,                          // llvm.x86.xop.vphsubbw
    x86_xop_vphsubdq,                          // llvm.x86.xop.vphsubdq
    x86_xop_vphsubwd,                          // llvm.x86.xop.vphsubwd
    x86_xop_vpmacsdd,                          // llvm.x86.xop.vpmacsdd
    x86_xop_vpmacsdqh,                         // llvm.x86.xop.vpmacsdqh
    x86_xop_vpmacsdql,                         // llvm.x86.xop.vpmacsdql
    x86_xop_vpmacssdd,                         // llvm.x86.xop.vpmacssdd
    x86_xop_vpmacssdqh,                        // llvm.x86.xop.vpmacssdqh
    x86_xop_vpmacssdql,                        // llvm.x86.xop.vpmacssdql
    x86_xop_vpmacsswd,                         // llvm.x86.xop.vpmacsswd
    x86_xop_vpmacssww,                         // llvm.x86.xop.vpmacssww
    x86_xop_vpmacswd,                          // llvm.x86.xop.vpmacswd
    x86_xop_vpmacsww,                          // llvm.x86.xop.vpmacsww
    x86_xop_vpmadcsswd,                        // llvm.x86.xop.vpmadcsswd
    x86_xop_vpmadcswd,                         // llvm.x86.xop.vpmadcswd
    x86_xop_vpperm,                            // llvm.x86.xop.vpperm
    x86_xop_vpshab,                            // llvm.x86.xop.vpshab
    x86_xop_vpshad,                            // llvm.x86.xop.vpshad
    x86_xop_vpshaq,                            // llvm.x86.xop.vpshaq
    x86_xop_vpshaw,                            // llvm.x86.xop.vpshaw
    x86_xop_vpshlb,                            // llvm.x86.xop.vpshlb
    x86_xop_vpshld,                            // llvm.x86.xop.vpshld
    x86_xop_vpshlq,                            // llvm.x86.xop.vpshlq
    x86_xop_vpshlw,                            // llvm.x86.xop.vpshlw
    x86_xresldtrk,                             // llvm.x86.xresldtrk
    x86_xrstor,                                // llvm.x86.xrstor
    x86_xrstor64,                              // llvm.x86.xrstor64
    x86_xrstors,                               // llvm.x86.xrstors
    x86_xrstors64,                             // llvm.x86.xrstors64
    x86_xsave,                                 // llvm.x86.xsave
    x86_xsave64,                               // llvm.x86.xsave64
    x86_xsavec,                                // llvm.x86.xsavec
    x86_xsavec64,                              // llvm.x86.xsavec64
    x86_xsaveopt,                              // llvm.x86.xsaveopt
    x86_xsaveopt64,                            // llvm.x86.xsaveopt64
    x86_xsaves,                                // llvm.x86.xsaves
    x86_xsaves64,                              // llvm.x86.xsaves64
    x86_xsetbv,                                // llvm.x86.xsetbv
    x86_xsusldtrk,                             // llvm.x86.xsusldtrk
    x86_xtest,                                 // llvm.x86.xtest
}; // enum
} // namespace llvm::Intrinsic
#endif

